"""
Python module generated from Java source file org.bukkit.util.FileUtil

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from java.io import FileInputStream
from java.io import FileOutputStream
from java.io import IOException
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class FileUtil:
    """
    Class containing file utilities
    """

    @staticmethod
    def copy(inFile: "File", outFile: "File") -> bool:
        """
        This method copies one file to another location

        Arguments
        - inFile: the source filename
        - outFile: the target filename

        Returns
        - True on success
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.TimeUnit

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.time import Duration
from java.time.temporal import ChronoUnit
from java.util import Objects
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class TimeUnit(Enum):
    """
    A `TimeUnit` represents time durations at a given unit of
    granularity and provides utility methods to convert across units,
    and to perform timing and delay operations in these units.  A
    `TimeUnit` does not maintain time information, but only
    helps organize and use time representations that may be maintained
    separately across various contexts.  A nanosecond is defined as one
    thousandth of a microsecond, a microsecond as one thousandth of a
    millisecond, a millisecond as one thousandth of a second, a minute
    as sixty seconds, an hour as sixty minutes, and a day as twenty four
    hours.
    
    A `TimeUnit` is mainly used to inform time-based methods
    how a given timing parameter should be interpreted. For example,
    the following code will timeout in 50 milliseconds if the java.util.concurrent.locks.Lock lock is not available:
    
    ``` `Lock lock = ...;
    if (lock.tryLock(50L, TimeUnit.MILLISECONDS)) ...````
    
    while this code will timeout in 50 seconds:
    ``` `Lock lock = ...;
    if (lock.tryLock(50L, TimeUnit.SECONDS)) ...````
    
    Note however, that there is no guarantee that a particular timeout
    implementation will be able to notice the passage of time at the
    same granularity as the given `TimeUnit`.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    NANOSECONDS = (TimeUnit.NANO_SCALE)
    """
    Time unit representing one thousandth of a microsecond.
    """
    MICROSECONDS = (TimeUnit.MICRO_SCALE)
    """
    Time unit representing one thousandth of a millisecond.
    """
    MILLISECONDS = (TimeUnit.MILLI_SCALE)
    """
    Time unit representing one thousandth of a second.
    """
    SECONDS = (TimeUnit.SECOND_SCALE)
    """
    Time unit representing one second.
    """
    MINUTES = (TimeUnit.MINUTE_SCALE)
    """
    Time unit representing sixty seconds.

    Since
    - 1.6
    """
    HOURS = (TimeUnit.HOUR_SCALE)
    """
    Time unit representing sixty minutes.

    Since
    - 1.6
    """
    DAYS = (TimeUnit.DAY_SCALE)
    """
    Time unit representing twenty four hours.

    Since
    - 1.6
    """


    def convert(self, sourceDuration: int, sourceUnit: "TimeUnit") -> int:
        """
        Converts the given time duration in the given unit to this unit.
        Conversions from finer to coarser granularities truncate, so
        lose precision. For example, converting `999` milliseconds
        to seconds results in `0`. Conversions from coarser to
        finer granularities with arguments that would numerically
        overflow saturate to `Long.MIN_VALUE` if negative or
        `Long.MAX_VALUE` if positive.
        
        For example, to convert 10 minutes to milliseconds, use:
        `TimeUnit.MILLISECONDS.convert(10L, TimeUnit.MINUTES)`

        Arguments
        - sourceDuration: the time duration in the given `sourceUnit`
        - sourceUnit: the unit of the `sourceDuration` argument

        Returns
        - the converted duration in this unit,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.
        """
        ...


    def convert(self, duration: "Duration") -> int:
        """
        Converts the given time duration to this unit.
        
        For any TimeUnit `unit`,
        `unit.convert(Duration.ofNanos(n))`
        is equivalent to
        `unit.convert(n, NANOSECONDS)`, and
        `unit.convert(Duration.of(n, unit.toChronoUnit()))`
        is equivalent to `n` (in the absence of overflow).

        Arguments
        - duration: the time duration

        Returns
        - the converted duration in this unit,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.

        Raises
        - NullPointerException: if `duration` is null

        See
        - Duration.of(long,TemporalUnit)

        Since
        - 11

        Unknown Tags
        - This method differs from Duration.toNanos() in that it
        does not throw ArithmeticException on numeric overflow.
        """
        ...


    def toNanos(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) NANOSECONDS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.
        """
        ...


    def toMicros(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) MICROSECONDS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.
        """
        ...


    def toMillis(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) MILLISECONDS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.
        """
        ...


    def toSeconds(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) SECONDS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.
        """
        ...


    def toMinutes(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) MINUTES.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.

        Since
        - 1.6
        """
        ...


    def toHours(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) HOURS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration,
        or `Long.MIN_VALUE` if conversion would negatively overflow,
        or `Long.MAX_VALUE` if it would positively overflow.

        Since
        - 1.6
        """
        ...


    def toDays(self, duration: int) -> int:
        """
        Equivalent to
        .convert(long, TimeUnit) DAYS.convert(duration, this).

        Arguments
        - duration: the duration

        Returns
        - the converted duration

        Since
        - 1.6
        """
        ...


    def timedWait(self, obj: "Object", timeout: int) -> None:
        """
        Performs a timed Object.wait(long, int) Object.wait
        using this time unit.
        This is a convenience method that converts timeout arguments
        into the form required by the `Object.wait` method.
        
        For example, you could implement a blocking `poll` method
        (see BlockingQueue.poll(long, TimeUnit) BlockingQueue.poll)
        using:
        
        ``` `public E poll(long timeout, TimeUnit unit)
            throws InterruptedException {
          synchronized (lock) {
            while (isEmpty()) {
              unit.timedWait(lock, timeout);
              ...`
          }
        }}```

        Arguments
        - obj: the object to wait on
        - timeout: the maximum time to wait. If less than
        or equal to zero, do not wait at all.

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def timedJoin(self, thread: "Thread", timeout: int) -> None:
        """
        Performs a timed Thread.join(long, int) Thread.join
        using this time unit.
        This is a convenience method that converts time arguments into the
        form required by the `Thread.join` method.

        Arguments
        - thread: the thread to wait for
        - timeout: the maximum time to wait. If less than
        or equal to zero, do not wait at all.

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def sleep(self, timeout: int) -> None:
        """
        Performs a Thread.sleep(long, int) Thread.sleep using
        this time unit.
        This is a convenience method that converts time arguments into the
        form required by the `Thread.sleep` method.

        Arguments
        - timeout: the minimum time to sleep. If less than
        or equal to zero, do not sleep at all.

        Raises
        - InterruptedException: if interrupted while sleeping
        """
        ...


    def toChronoUnit(self) -> "ChronoUnit":
        """
        Converts this `TimeUnit` to the equivalent `ChronoUnit`.

        Returns
        - the converted equivalent ChronoUnit

        Since
        - 9
        """
        ...


    @staticmethod
    def of(chronoUnit: "ChronoUnit") -> "TimeUnit":
        """
        Converts a `ChronoUnit` to the equivalent `TimeUnit`.

        Arguments
        - chronoUnit: the ChronoUnit to convert

        Returns
        - the converted equivalent TimeUnit

        Raises
        - IllegalArgumentException: if `chronoUnit` has no
                equivalent TimeUnit
        - NullPointerException: if `chronoUnit` is null

        Since
        - 9
        """
        ...



"""
Python module generated from Java source file java.util.RandomAccess

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class RandomAccess:
    """
    Marker interface used by `List` implementations to indicate that
    they support fast (generally constant time) random access.  The primary
    purpose of this interface is to allow generic algorithms to alter their
    behavior to provide good performance when applied to either random or
    sequential access lists.
    
    The best algorithms for manipulating random access lists (such as
    `ArrayList`) can produce quadratic behavior when applied to
    sequential access lists (such as `LinkedList`).  Generic list
    algorithms are encouraged to check whether the given list is an
    `instanceof` this interface before applying an algorithm that would
    provide poor performance if it were applied to a sequential access list,
    and to alter their behavior if necessary to guarantee acceptable
    performance.
    
    It is recognized that the distinction between random and sequential
    access is often fuzzy.  For example, some `List` implementations
    provide asymptotically linear access times if they get huge, but constant
    access times in practice.  Such a `List` implementation
    should generally implement this interface.  As a rule of thumb, a
    `List` implementation should implement this interface if,
    for typical instances of the class, this loop:
    ```
        for (int i=0, n=list.size(); i &lt; n; i++)
            list.get(i);
    ```
    runs faster than this loop:
    ```
        for (Iterator i=list.iterator(); i.hasNext(); )
            i.next();
    ```
    
    This interface is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.

    Since
    - 1.4
    """





from .IOException import IOException
from .InputStreamReader import InputStreamReader
from .Reader import Reader
from .StringReader import StringReader
from .StringWriter import StringWriter
from .Writer import Writer
from .EOFException import EOFException
from .Closeable import Closeable
from .Flushable import Flushable
from .ObjectInputStream import ObjectInputStream
from .ObjectStreamClass import ObjectStreamClass
from .InvalidObjectException import InvalidObjectException
from .ObjectStreamException import ObjectStreamException
from .Serializable import Serializable
from .ObjectOutputStream import ObjectOutputStream
from .File import File
from .InputStream import InputStream
from .OutputStream import OutputStream
from .FilenameFilter import FilenameFilter
from .DataOutput import DataOutput
from .DataOutputStream import DataOutputStream
from .FilterOutputStream import FilterOutputStream
from .DataInput import DataInput
from .DataInputStream import DataInputStream
from .FilterInputStream import FilterInputStream
from .BufferedReader import BufferedReader
from .BufferedWriter import BufferedWriter
from .FileInputStream import FileInputStream
from .FileNotFoundException import FileNotFoundException
from .FileOutputStream import FileOutputStream
from .OutputStreamWriter import OutputStreamWriter
from .RandomAccessFile import RandomAccessFile
from .ByteArrayInputStream import ByteArrayInputStream
from .ByteArrayOutputStream import ByteArrayOutputStream
from .UncheckedIOException import UncheckedIOException
from .BufferedInputStream import BufferedInputStream
from .BufferedOutputStream import BufferedOutputStream
from .PrintWriter import PrintWriter
from .Externalizable import Externalizable
from .ObjectInput import ObjectInput
from .ObjectOutput import ObjectOutput
from .UnsupportedEncodingException import UnsupportedEncodingException
from .PushbackInputStream import PushbackInputStream
from .PrintStream import PrintStream


"""
Python module generated from Java source file com.google.gson.annotations.Expose

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.annotations import *
from typing import Any, Callable, Iterable, Tuple


class Expose:
    """
    An annotation that indicates this member should be exposed for JSON serialization or
    deserialization.
    
    This annotation has no effect unless you build com.google.gson.Gson with a com.google.gson.GsonBuilder and invoke com.google.gson.GsonBuilder.excludeFieldsWithoutExposeAnnotation() method.
    
    Here is an example of how this annotation is meant to be used:
    
    ```
    public class User {
      &#64;Expose private String firstName;
      &#64;Expose(serialize = False) private String lastName;
      &#64;Expose (serialize = False, deserialize = False) private String emailAddress;
      private String password;
    }
    ```
    
    If you created Gson with `new Gson()`, the `toJson()` and `fromJson()` methods
    will use the `password` field along-with `firstName`, `lastName`, and `emailAddress` for serialization and deserialization. However, if you created Gson with `Gson gson = new GsonBuilder().excludeFieldsWithoutExposeAnnotation().create()` then the `toJson()` and `fromJson()` methods of Gson will exclude the `password` field. This is
    because the `password` field is not marked with the `@Expose` annotation. Gson will
    also exclude `lastName` and `emailAddress` from serialization since `serialize`
    is set to `False`. Similarly, Gson will exclude `emailAddress` from deserialization
    since `deserialize` is set to False.
    
    Note that another way to achieve the same effect would have been to just mark the `password` field as `transient`, and Gson would have excluded it even with default settings.
    The `@Expose` annotation is useful in a style of programming where you want to explicitly
    specify all fields that should get considered for serialization or deserialization.

    Author(s)
    - Joel Leitch
    """

    def serialize(self) -> bool:
        """
        If `True`, the field marked with this annotation is written out in the JSON while
        serializing. If `False`, the field marked with this annotation is skipped from the
        serialized output. Defaults to `True`.

        Since
        - 1.4
        """
        return True


    def deserialize(self) -> bool:
        """
        If `True`, the field marked with this annotation is deserialized from the JSON. If `False`, the field marked with this annotation is skipped during deserialization. Defaults to
        `True`.

        Since
        - 1.4
        """
        return True



"""
Python module generated from Java source file com.google.common.hash.AbstractCompositeHashFunction

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from com.google.errorprone.annotations import Immutable
from java.nio.charset import Charset
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractCompositeHashFunction(AbstractHashFunction):
    """
    An abstract composition of multiple hash functions. .newHasher() delegates to the
    `Hasher` objects of the delegate hash functions, and in the end, they are used by
    .makeHash(Hasher[]) that constructs the final `HashCode`.

    Author(s)
    - Dimitris Andreou
    """

    def newHasher(self) -> "Hasher":
        ...


    def newHasher(self, expectedInputSize: int) -> "Hasher":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Switch

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import Directional
from org.bukkit.block.data import FaceAttachable
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Switch(Directional, FaceAttachable, Powerable):

    def getFace(self) -> "Face":
        """
        Gets the value of the 'face' property.

        Returns
        - the 'face' value

        Deprecated
        - use .getAttachedFace()
        """
        ...


    def setFace(self, face: "Face") -> None:
        """
        Sets the value of the 'face' property.

        Arguments
        - face: the new 'face' value

        Deprecated
        - use .getAttachedFace()
        """
        ...


    class Face(Enum):
        """
        The face to which a switch type block is stuck.

        Deprecated
        - use AttachedFace
        """

        FLOOR = 0
        """
        The switch is mounted to the floor and pointing upwards.
        """
        WALL = 1
        """
        The switch is mounted to the wall.
        """
        CEILING = 2
        """
        The switch is mounted to the ceiling and pointing dowanrds.
        """



"""
Python module generated from Java source file java.util.stream.Collectors

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import AbstractSet
from java.util import Collections
from java.util import Comparator
from java.util import DoubleSummaryStatistics
from java.util import EnumSet
from java.util import IntSummaryStatistics
from java.util import Iterator
from java.util import LongSummaryStatistics
from java.util import Objects
from java.util import Optional
from java.util import StringJoiner
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import BinaryOperator
from java.util.function import Consumer
from java.util.function import Function
from java.util.function import Predicate
from java.util.function import Supplier
from java.util.function import ToDoubleFunction
from java.util.function import ToIntFunction
from java.util.function import ToLongFunction
from java.util.stream import *
from jdk.internal.access import SharedSecrets
from typing import Any, Callable, Iterable, Tuple


class Collectors:
    """
    Implementations of Collector that implement various useful reduction
    operations, such as accumulating elements into collections, summarizing
    elements according to various criteria, etc.
    
    The following are examples of using the predefined collectors to perform
    common mutable reduction tasks:
    
    ````// Accumulate names into a List
    List<String> list = people.stream()
      .map(Person::getName)
      .collect(Collectors.toList());
    
    // Accumulate names into a TreeSet
    Set<String> set = people.stream()
      .map(Person::getName)
      .collect(Collectors.toCollection(TreeSet::new));
    
    // Convert elements to strings and concatenate them, separated by commas
    String joined = things.stream()
      .map(Object::toString)
      .collect(Collectors.joining(", "));
    
    // Compute sum of salaries of employee
    int total = employees.stream()
      .collect(Collectors.summingInt(Employee::getSalary));
    
    // Group employees by department
    Map<Department, List<Employee>> byDept = employees.stream()
      .collect(Collectors.groupingBy(Employee::getDepartment));
    
    // Compute sum of salaries by department
    Map<Department, Integer> totalByDept = employees.stream()
      .collect(Collectors.groupingBy(Employee::getDepartment,
                                     Collectors.summingInt(Employee::getSalary)));
    
    // Partition students into passing and failing
    Map<Boolean, List<Student>> passingFailing = students.stream()
      .collect(Collectors.partitioningBy(s -> s.getGrade() >= PASS_THRESHOLD));````

    Since
    - 1.8
    """

    @staticmethod
    def toCollection(collectionFactory: "Supplier"["C"]) -> "Collector"["T", Any, "C"]:
        """
        Returns a `Collector` that accumulates the input elements into a
        new `Collection`, in encounter order.  The `Collection` is
        created by the provided factory.
        
        Type `<T>`: the type of the input elements
        
        Type `<C>`: the type of the resulting `Collection`

        Arguments
        - collectionFactory: a supplier providing a new empty `Collection`
                                 into which the results will be inserted

        Returns
        - a `Collector` which collects all the input elements into a
        `Collection`, in encounter order
        """
        ...


    @staticmethod
    def toList() -> "Collector"["T", Any, list["T"]]:
        """
        Returns a `Collector` that accumulates the input elements into a
        new `List`. There are no guarantees on the type, mutability,
        serializability, or thread-safety of the `List` returned; if more
        control over the returned `List` is required, use .toCollection(Supplier).
        
        Type `<T>`: the type of the input elements

        Returns
        - a `Collector` which collects all the input elements into a
        `List`, in encounter order
        """
        ...


    @staticmethod
    def toUnmodifiableList() -> "Collector"["T", Any, list["T"]]:
        """
        Returns a `Collector` that accumulates the input elements into an
        <a href="../List.html#unmodifiable">unmodifiable List</a> in encounter
        order. The returned Collector disallows null values and will throw
        `NullPointerException` if it is presented with a null value.
        
        Type `<T>`: the type of the input elements

        Returns
        - a `Collector` that accumulates the input elements into an
        <a href="../List.html#unmodifiable">unmodifiable List</a> in encounter order

        Since
        - 10
        """
        ...


    @staticmethod
    def toSet() -> "Collector"["T", Any, set["T"]]:
        """
        Returns a `Collector` that accumulates the input elements into a
        new `Set`. There are no guarantees on the type, mutability,
        serializability, or thread-safety of the `Set` returned; if more
        control over the returned `Set` is required, use
        .toCollection(Supplier).
        
        This is an Collector.Characteristics.UNORDERED unordered
        Collector.
        
        Type `<T>`: the type of the input elements

        Returns
        - a `Collector` which collects all the input elements into a
        `Set`
        """
        ...


    @staticmethod
    def toUnmodifiableSet() -> "Collector"["T", Any, set["T"]]:
        """
        Returns a `Collector` that accumulates the input elements into an
        <a href="../Set.html#unmodifiable">unmodifiable Set</a>. The returned
        Collector disallows null values and will throw `NullPointerException`
        if it is presented with a null value. If the input contains duplicate elements,
        an arbitrary element of the duplicates is preserved.
        
        This is an Collector.Characteristics.UNORDERED unordered
        Collector.
        
        Type `<T>`: the type of the input elements

        Returns
        - a `Collector` that accumulates the input elements into an
        <a href="../Set.html#unmodifiable">unmodifiable Set</a>

        Since
        - 10
        """
        ...


    @staticmethod
    def joining() -> "Collector"["CharSequence", Any, str]:
        """
        Returns a `Collector` that concatenates the input elements into a
        `String`, in encounter order.

        Returns
        - a `Collector` that concatenates the input elements into a
        `String`, in encounter order
        """
        ...


    @staticmethod
    def joining(delimiter: "CharSequence") -> "Collector"["CharSequence", Any, str]:
        """
        Returns a `Collector` that concatenates the input elements,
        separated by the specified delimiter, in encounter order.

        Arguments
        - delimiter: the delimiter to be used between each element

        Returns
        - A `Collector` which concatenates CharSequence elements,
        separated by the specified delimiter, in encounter order
        """
        ...


    @staticmethod
    def joining(delimiter: "CharSequence", prefix: "CharSequence", suffix: "CharSequence") -> "Collector"["CharSequence", Any, str]:
        """
        Returns a `Collector` that concatenates the input elements,
        separated by the specified delimiter, with the specified prefix and
        suffix, in encounter order.

        Arguments
        - delimiter: the delimiter to be used between each element
        - prefix: the sequence of characters to be used at the beginning
                       of the joined result
        - suffix: the sequence of characters to be used at the end
                       of the joined result

        Returns
        - A `Collector` which concatenates CharSequence elements,
        separated by the specified delimiter, in encounter order
        """
        ...


    @staticmethod
    def mapping(mapper: "Function"["T", "U"], downstream: "Collector"["U", "A", "R"]) -> "Collector"["T", Any, "R"]:
        """
        Adapts a `Collector` accepting elements of type `U` to one
        accepting elements of type `T` by applying a mapping function to
        each input element before accumulation.
        
        Type `<T>`: the type of the input elements
        
        Type `<U>`: type of elements accepted by downstream collector
        
        Type `<A>`: intermediate accumulation type of the downstream collector
        
        Type `<R>`: result type of collector

        Arguments
        - mapper: a function to be applied to the input elements
        - downstream: a collector which will accept mapped values

        Returns
        - a collector which applies the mapping function to the input
        elements and provides the mapped results to the downstream collector

        Unknown Tags
        - The `mapping()` collectors are most useful when used in a
        multi-level reduction, such as downstream of a `groupingBy` or
        `partitioningBy`.  For example, given a stream of
        `Person`, to accumulate the set of last names in each city:
        ````Map<City, Set<String>> lastNamesByCity
          = people.stream().collect(
            groupingBy(Person::getCity,
                       mapping(Person::getLastName,
                               toSet())));````
        """
        ...


    @staticmethod
    def flatMapping(mapper: "Function"["T", "Stream"["U"]], downstream: "Collector"["U", "A", "R"]) -> "Collector"["T", Any, "R"]:
        """
        Adapts a `Collector` accepting elements of type `U` to one
        accepting elements of type `T` by applying a flat mapping function
        to each input element before accumulation.  The flat mapping function
        maps an input element to a Stream stream covering zero or more
        output elements that are then accumulated downstream.  Each mapped stream
        is java.util.stream.BaseStream.close() closed after its contents
        have been placed downstream.  (If a mapped stream is `null`
        an empty stream is used, instead.)
        
        Type `<T>`: the type of the input elements
        
        Type `<U>`: type of elements accepted by downstream collector
        
        Type `<A>`: intermediate accumulation type of the downstream collector
        
        Type `<R>`: result type of collector

        Arguments
        - mapper: a function to be applied to the input elements, which
        returns a stream of results
        - downstream: a collector which will receive the elements of the
        stream returned by mapper

        Returns
        - a collector which applies the mapping function to the input
        elements and provides the flat mapped results to the downstream collector

        Since
        - 9

        Unknown Tags
        - The `flatMapping()` collectors are most useful when used in a
        multi-level reduction, such as downstream of a `groupingBy` or
        `partitioningBy`.  For example, given a stream of
        `Order`, to accumulate the set of line items for each customer:
        ````Map<String, Set<LineItem>> itemsByCustomerName
          = orders.stream().collect(
            groupingBy(Order::getCustomerName,
                       flatMapping(order -> order.getLineItems().stream(),
                                   toSet())));````
        """
        ...


    @staticmethod
    def filtering(predicate: "Predicate"["T"], downstream: "Collector"["T", "A", "R"]) -> "Collector"["T", Any, "R"]:
        """
        Adapts a `Collector` to one accepting elements of the same type
        `T` by applying the predicate to each input element and only
        accumulating if the predicate returns `True`.
        
        Type `<T>`: the type of the input elements
        
        Type `<A>`: intermediate accumulation type of the downstream collector
        
        Type `<R>`: result type of collector

        Arguments
        - predicate: a predicate to be applied to the input elements
        - downstream: a collector which will accept values that match the
        predicate

        Returns
        - a collector which applies the predicate to the input elements
        and provides matching elements to the downstream collector

        Since
        - 9

        Unknown Tags
        - The `filtering()` collectors are most useful when used in a
        multi-level reduction, such as downstream of a `groupingBy` or
        `partitioningBy`.  For example, given a stream of
        `Employee`, to accumulate the employees in each department that have a
        salary above a certain threshold:
        ````Map<Department, Set<Employee>> wellPaidEmployeesByDepartment
          = employees.stream().collect(
            groupingBy(Employee::getDepartment,
                       filtering(e -> e.getSalary() > 2000,
                                 toSet())));````
        A filtering collector differs from a stream's `filter()` operation.
        In this example, suppose there are no employees whose salary is above the
        threshold in some department.  Using a filtering collector as shown above
        would result in a mapping from that department to an empty `Set`.
        If a stream `filter()` operation were done instead, there would be
        no mapping for that department at all.
        """
        ...


    @staticmethod
    def collectingAndThen(downstream: "Collector"["T", "A", "R"], finisher: "Function"["R", "RR"]) -> "Collector"["T", "A", "RR"]:
        """
        Adapts a `Collector` to perform an additional finishing
        transformation.  For example, one could adapt the .toList()
        collector to always produce an immutable list with:
        ````List<String> list = people.stream().collect(
          collectingAndThen(toList(),
                            Collections::unmodifiableList));````
        
        Type `<T>`: the type of the input elements
        
        Type `<A>`: intermediate accumulation type of the downstream collector
        
        Type `<R>`: result type of the downstream collector

        Arguments
        - <RR>: result type of the resulting collector
        - downstream: a collector
        - finisher: a function to be applied to the final result of the downstream collector

        Returns
        - a collector which performs the action of the downstream collector,
        followed by an additional finishing step
        """
        ...


    @staticmethod
    def counting() -> "Collector"["T", Any, "Long"]:
        """
        Returns a `Collector` accepting elements of type `T` that
        counts the number of input elements.  If no elements are present, the
        result is 0.
        
        Type `<T>`: the type of the input elements

        Returns
        - a `Collector` that counts the input elements

        Unknown Tags
        - This produces a result equivalent to:
        ````reducing(0L, e -> 1L, Long::sum)````
        """
        ...


    @staticmethod
    def minBy(comparator: "Comparator"["T"]) -> "Collector"["T", Any, "Optional"["T"]]:
        """
        Returns a `Collector` that produces the minimal element according
        to a given `Comparator`, described as an `Optional<T>`.
        
        Type `<T>`: the type of the input elements

        Arguments
        - comparator: a `Comparator` for comparing elements

        Returns
        - a `Collector` that produces the minimal value

        Unknown Tags
        - This produces a result equivalent to:
        ````reducing(BinaryOperator.minBy(comparator))````
        """
        ...


    @staticmethod
    def maxBy(comparator: "Comparator"["T"]) -> "Collector"["T", Any, "Optional"["T"]]:
        """
        Returns a `Collector` that produces the maximal element according
        to a given `Comparator`, described as an `Optional<T>`.
        
        Type `<T>`: the type of the input elements

        Arguments
        - comparator: a `Comparator` for comparing elements

        Returns
        - a `Collector` that produces the maximal value

        Unknown Tags
        - This produces a result equivalent to:
        ````reducing(BinaryOperator.maxBy(comparator))````
        """
        ...


    @staticmethod
    def summingInt(mapper: "ToIntFunction"["T"]) -> "Collector"["T", Any, "Integer"]:
        """
        Returns a `Collector` that produces the sum of a integer-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be summed

        Returns
        - a `Collector` that produces the sum of a derived property
        """
        ...


    @staticmethod
    def summingLong(mapper: "ToLongFunction"["T"]) -> "Collector"["T", Any, "Long"]:
        """
        Returns a `Collector` that produces the sum of a long-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be summed

        Returns
        - a `Collector` that produces the sum of a derived property
        """
        ...


    @staticmethod
    def summingDouble(mapper: "ToDoubleFunction"["T"]) -> "Collector"["T", Any, "Double"]:
        """
        Returns a `Collector` that produces the sum of a double-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        The sum returned can vary depending upon the order in which
        values are recorded, due to accumulated rounding error in
        addition of values of differing magnitudes. Values sorted by increasing
        absolute magnitude tend to yield more accurate results.  If any recorded
        value is a `NaN` or the sum is at any point a `NaN` then the
        sum will be `NaN`.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be summed

        Returns
        - a `Collector` that produces the sum of a derived property
        """
        ...


    @staticmethod
    def averagingInt(mapper: "ToIntFunction"["T"]) -> "Collector"["T", Any, "Double"]:
        """
        Returns a `Collector` that produces the arithmetic mean of an integer-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be averaged

        Returns
        - a `Collector` that produces the arithmetic mean of a
        derived property
        """
        ...


    @staticmethod
    def averagingLong(mapper: "ToLongFunction"["T"]) -> "Collector"["T", Any, "Double"]:
        """
        Returns a `Collector` that produces the arithmetic mean of a long-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be averaged

        Returns
        - a `Collector` that produces the arithmetic mean of a
        derived property
        """
        ...


    @staticmethod
    def averagingDouble(mapper: "ToDoubleFunction"["T"]) -> "Collector"["T", Any, "Double"]:
        """
        Returns a `Collector` that produces the arithmetic mean of a double-valued
        function applied to the input elements.  If no elements are present,
        the result is 0.
        
        The average returned can vary depending upon the order in which
        values are recorded, due to accumulated rounding error in
        addition of values of differing magnitudes. Values sorted by increasing
        absolute magnitude tend to yield more accurate results.  If any recorded
        value is a `NaN` or the sum is at any point a `NaN` then the
        average will be `NaN`.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a function extracting the property to be averaged

        Returns
        - a `Collector` that produces the arithmetic mean of a
        derived property

        Unknown Tags
        - The `double` format can represent all
        consecutive integers in the range -2<sup>53</sup> to
        2<sup>53</sup>. If the pipeline has more than 2<sup>53</sup>
        values, the divisor in the average computation will saturate at
        2<sup>53</sup>, leading to additional numerical errors.
        """
        ...


    @staticmethod
    def reducing(identity: "T", op: "BinaryOperator"["T"]) -> "Collector"["T", Any, "T"]:
        """
        Returns a `Collector` which performs a reduction of its
        input elements under a specified `BinaryOperator` using the
        provided identity.
        
        Type `<T>`: element type for the input and output of the reduction

        Arguments
        - identity: the identity value for the reduction (also, the value
                        that is returned when there are no input elements)
        - op: a `BinaryOperator<T>` used to reduce the input elements

        Returns
        - a `Collector` which implements the reduction operation

        See
        - .reducing(Object, Function, BinaryOperator)

        Unknown Tags
        - The `reducing()` collectors are most useful when used in a
        multi-level reduction, downstream of `groupingBy` or
        `partitioningBy`.  To perform a simple reduction on a stream,
        use Stream.reduce(Object, BinaryOperator)} instead.
        """
        ...


    @staticmethod
    def reducing(op: "BinaryOperator"["T"]) -> "Collector"["T", Any, "Optional"["T"]]:
        """
        Returns a `Collector` which performs a reduction of its
        input elements under a specified `BinaryOperator`.  The result
        is described as an `Optional<T>`.
        
        Type `<T>`: element type for the input and output of the reduction

        Arguments
        - op: a `BinaryOperator<T>` used to reduce the input elements

        Returns
        - a `Collector` which implements the reduction operation

        See
        - .reducing(Object, Function, BinaryOperator)

        Unknown Tags
        - The `reducing()` collectors are most useful when used in a
        multi-level reduction, downstream of `groupingBy` or
        `partitioningBy`.  To perform a simple reduction on a stream,
        use Stream.reduce(BinaryOperator) instead.
        
        For example, given a stream of `Person`, to calculate tallest
        person in each city:
        ````Comparator<Person> byHeight = Comparator.comparing(Person::getHeight);
        Map<City, Optional<Person>> tallestByCity
          = people.stream().collect(
            groupingBy(Person::getCity,
                       reducing(BinaryOperator.maxBy(byHeight))));````
        """
        ...


    @staticmethod
    def reducing(identity: "U", mapper: "Function"["T", "U"], op: "BinaryOperator"["U"]) -> "Collector"["T", Any, "U"]:
        """
        Returns a `Collector` which performs a reduction of its
        input elements under a specified mapping function and
        `BinaryOperator`. This is a generalization of
        .reducing(Object, BinaryOperator) which allows a transformation
        of the elements before reduction.
        
        Type `<T>`: the type of the input elements
        
        Type `<U>`: the type of the mapped values

        Arguments
        - identity: the identity value for the reduction (also, the value
                        that is returned when there are no input elements)
        - mapper: a mapping function to apply to each input value
        - op: a `BinaryOperator<U>` used to reduce the mapped values

        Returns
        - a `Collector` implementing the map-reduce operation

        See
        - .reducing(BinaryOperator)

        Unknown Tags
        - The `reducing()` collectors are most useful when used in a
        multi-level reduction, downstream of `groupingBy` or
        `partitioningBy`.  To perform a simple map-reduce on a stream,
        use Stream.map(Function) and Stream.reduce(Object, BinaryOperator)
        instead.
        
        For example, given a stream of `Person`, to calculate the longest
        last name of residents in each city:
        ````Comparator<String> byLength = Comparator.comparing(String::length);
        Map<City, String> longestLastNameByCity
          = people.stream().collect(
            groupingBy(Person::getCity,
                       reducing("",
                                Person::getLastName,
                                BinaryOperator.maxBy(byLength))));````
        """
        ...


    @staticmethod
    def groupingBy(classifier: "Function"["T", "K"]) -> "Collector"["T", Any, dict["K", list["T"]]]:
        """
        Returns a `Collector` implementing a "group by" operation on
        input elements of type `T`, grouping elements according to a
        classification function, and returning the results in a `Map`.
        
        The classification function maps elements to some key type `K`.
        The collector produces a `Map<K, List<T>>` whose keys are the
        values resulting from applying the classification function to the input
        elements, and whose corresponding values are `List`s containing the
        input elements which map to the associated key under the classification
        function.
        
        There are no guarantees on the type, mutability, serializability, or
        thread-safety of the `Map` or `List` objects returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys

        Arguments
        - classifier: the classifier function mapping input elements to keys

        Returns
        - a `Collector` implementing the group-by operation

        See
        - .groupingByConcurrent(Function)

        Unknown Tags
        - This produces a result similar to:
        ````groupingBy(classifier, toList());````
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If
        preservation of the order in which elements appear in the resulting `Map`
        collector is not required, using .groupingByConcurrent(Function)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def groupingBy(classifier: "Function"["T", "K"], downstream: "Collector"["T", "A", "D"]) -> "Collector"["T", Any, dict["K", "D"]]:
        """
        Returns a `Collector` implementing a cascaded "group by" operation
        on input elements of type `T`, grouping elements according to a
        classification function, and then performing a reduction operation on
        the values associated with a given key using the specified downstream
        `Collector`.
        
        The classification function maps elements to some key type `K`.
        The downstream collector operates on elements of type `T` and
        produces a result of type `D`. The resulting collector produces a
        `Map<K, D>`.
        
        There are no guarantees on the type, mutability,
        serializability, or thread-safety of the `Map` returned.
        
        For example, to compute the set of last names of people in each city:
        ````Map<City, Set<String>> namesByCity
          = people.stream().collect(
            groupingBy(Person::getCity,
                       mapping(Person::getLastName,
                               toSet())));````
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys
        
        Type `<A>`: the intermediate accumulation type of the downstream collector
        
        Type `<D>`: the result type of the downstream reduction

        Arguments
        - classifier: a classifier function mapping input elements to keys
        - downstream: a `Collector` implementing the downstream reduction

        Returns
        - a `Collector` implementing the cascaded group-by operation

        See
        - .groupingByConcurrent(Function, Collector)

        Unknown Tags
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If
        preservation of the order in which elements are presented to the downstream
        collector is not required, using .groupingByConcurrent(Function, Collector)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def groupingBy(classifier: "Function"["T", "K"], mapFactory: "Supplier"["M"], downstream: "Collector"["T", "A", "D"]) -> "Collector"["T", Any, "M"]:
        """
        Returns a `Collector` implementing a cascaded "group by" operation
        on input elements of type `T`, grouping elements according to a
        classification function, and then performing a reduction operation on
        the values associated with a given key using the specified downstream
        `Collector`.  The `Map` produced by the Collector is created
        with the supplied factory function.
        
        The classification function maps elements to some key type `K`.
        The downstream collector operates on elements of type `T` and
        produces a result of type `D`. The resulting collector produces a
        `Map<K, D>`.
        
        For example, to compute the set of last names of people in each city,
        where the city names are sorted:
        ````Map<City, Set<String>> namesByCity
          = people.stream().collect(
            groupingBy(Person::getCity,
                       TreeMap::new,
                       mapping(Person::getLastName,
                               toSet())));````
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys
        
        Type `<A>`: the intermediate accumulation type of the downstream collector
        
        Type `<D>`: the result type of the downstream reduction
        
        Type `<M>`: the type of the resulting `Map`

        Arguments
        - classifier: a classifier function mapping input elements to keys
        - downstream: a `Collector` implementing the downstream reduction
        - mapFactory: a supplier providing a new empty `Map`
                          into which the results will be inserted

        Returns
        - a `Collector` implementing the cascaded group-by operation

        See
        - .groupingByConcurrent(Function, Supplier, Collector)

        Unknown Tags
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If
        preservation of the order in which elements are presented to the downstream
        collector is not required, using .groupingByConcurrent(Function, Supplier, Collector)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def groupingByConcurrent(classifier: "Function"["T", "K"]) -> "Collector"["T", Any, "ConcurrentMap"["K", list["T"]]]:
        """
        Returns a concurrent `Collector` implementing a "group by"
        operation on input elements of type `T`, grouping elements
        according to a classification function.
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        
        The classification function maps elements to some key type `K`.
        The collector produces a `ConcurrentMap<K, List<T>>` whose keys are the
        values resulting from applying the classification function to the input
        elements, and whose corresponding values are `List`s containing the
        input elements which map to the associated key under the classification
        function.
        
        There are no guarantees on the type, mutability, or serializability
        of the `ConcurrentMap` or `List` objects returned, or of the
        thread-safety of the `List` objects returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys

        Arguments
        - classifier: a classifier function mapping input elements to keys

        Returns
        - a concurrent, unordered `Collector` implementing the group-by operation

        See
        - .groupingByConcurrent(Function, Supplier, Collector)

        Unknown Tags
        - This produces a result similar to:
        ````groupingByConcurrent(classifier, toList());````
        """
        ...


    @staticmethod
    def groupingByConcurrent(classifier: "Function"["T", "K"], downstream: "Collector"["T", "A", "D"]) -> "Collector"["T", Any, "ConcurrentMap"["K", "D"]]:
        """
        Returns a concurrent `Collector` implementing a cascaded "group by"
        operation on input elements of type `T`, grouping elements
        according to a classification function, and then performing a reduction
        operation on the values associated with a given key using the specified
        downstream `Collector`.
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        
        The classification function maps elements to some key type `K`.
        The downstream collector operates on elements of type `T` and
        produces a result of type `D`. The resulting collector produces a
        `ConcurrentMap<K, D>`.
        
        There are no guarantees on the type, mutability, or serializability
        of the `ConcurrentMap` returned.
        
        For example, to compute the set of last names of people in each city,
        where the city names are sorted:
        ````ConcurrentMap<City, Set<String>> namesByCity
          = people.stream().collect(
            groupingByConcurrent(Person::getCity,
                                 mapping(Person::getLastName,
                                         toSet())));````
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys
        
        Type `<A>`: the intermediate accumulation type of the downstream collector
        
        Type `<D>`: the result type of the downstream reduction

        Arguments
        - classifier: a classifier function mapping input elements to keys
        - downstream: a `Collector` implementing the downstream reduction

        Returns
        - a concurrent, unordered `Collector` implementing the cascaded group-by operation

        See
        - .groupingByConcurrent(Function, Supplier, Collector)
        """
        ...


    @staticmethod
    def groupingByConcurrent(classifier: "Function"["T", "K"], mapFactory: "Supplier"["M"], downstream: "Collector"["T", "A", "D"]) -> "Collector"["T", Any, "M"]:
        """
        Returns a concurrent `Collector` implementing a cascaded "group by"
        operation on input elements of type `T`, grouping elements
        according to a classification function, and then performing a reduction
        operation on the values associated with a given key using the specified
        downstream `Collector`.  The `ConcurrentMap` produced by the
        Collector is created with the supplied factory function.
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        
        The classification function maps elements to some key type `K`.
        The downstream collector operates on elements of type `T` and
        produces a result of type `D`. The resulting collector produces a
        `ConcurrentMap<K, D>`.
        
        For example, to compute the set of last names of people in each city,
        where the city names are sorted:
        ````ConcurrentMap<City, Set<String>> namesByCity
          = people.stream().collect(
            groupingByConcurrent(Person::getCity,
                                 ConcurrentSkipListMap::new,
                                 mapping(Person::getLastName,
                                         toSet())));````
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the type of the keys
        
        Type `<A>`: the intermediate accumulation type of the downstream collector
        
        Type `<D>`: the result type of the downstream reduction
        
        Type `<M>`: the type of the resulting `ConcurrentMap`

        Arguments
        - classifier: a classifier function mapping input elements to keys
        - downstream: a `Collector` implementing the downstream reduction
        - mapFactory: a supplier providing a new empty `ConcurrentMap`
                          into which the results will be inserted

        Returns
        - a concurrent, unordered `Collector` implementing the cascaded group-by operation

        See
        - .groupingBy(Function, Supplier, Collector)
        """
        ...


    @staticmethod
    def partitioningBy(predicate: "Predicate"["T"]) -> "Collector"["T", Any, dict["Boolean", list["T"]]]:
        """
        Returns a `Collector` which partitions the input elements according
        to a `Predicate`, and organizes them into a
        `Map<Boolean, List<T>>`.
        
        The returned `Map` always contains mappings for both
        `False` and `True` keys.
        There are no guarantees on the type, mutability,
        serializability, or thread-safety of the `Map` or `List`
        returned.
        
        Type `<T>`: the type of the input elements

        Arguments
        - predicate: a predicate used for classifying input elements

        Returns
        - a `Collector` implementing the partitioning operation

        See
        - .partitioningBy(Predicate, Collector)

        Unknown Tags
        - If a partition has no elements, its value in the result Map will be
        an empty List.
        """
        ...


    @staticmethod
    def partitioningBy(predicate: "Predicate"["T"], downstream: "Collector"["T", "A", "D"]) -> "Collector"["T", Any, dict["Boolean", "D"]]:
        """
        Returns a `Collector` which partitions the input elements according
        to a `Predicate`, reduces the values in each partition according to
        another `Collector`, and organizes them into a
        `Map<Boolean, D>` whose values are the result of the downstream
        reduction.
        
        
        The returned `Map` always contains mappings for both
        `False` and `True` keys.
        There are no guarantees on the type, mutability,
        serializability, or thread-safety of the `Map` returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<A>`: the intermediate accumulation type of the downstream collector
        
        Type `<D>`: the result type of the downstream reduction

        Arguments
        - predicate: a predicate used for classifying input elements
        - downstream: a `Collector` implementing the downstream
                          reduction

        Returns
        - a `Collector` implementing the cascaded partitioning
                operation

        See
        - .partitioningBy(Predicate)

        Unknown Tags
        - If a partition has no elements, its value in the result Map will be
        obtained by calling the downstream collector's supplier function and then
        applying the finisher function.
        """
        ...


    @staticmethod
    def toMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"]) -> "Collector"["T", Any, dict["K", "U"]]:
        """
        Returns a `Collector` that accumulates elements into a
        `Map` whose keys and values are the result of applying the provided
        mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to
        Object.equals(Object)), an `IllegalStateException` is
        thrown when the collection operation is performed.  If the mapped keys
        might have duplicates, use .toMap(Function, Function, BinaryOperator)
        instead.
        
        There are no guarantees on the type, mutability, serializability,
        or thread-safety of the `Map` returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: a mapping function to produce keys
        - valueMapper: a mapping function to produce values

        Returns
        - a `Collector` which collects elements into a `Map`
        whose keys and values are the result of applying mapping functions to
        the input elements

        See
        - .toConcurrentMap(Function, Function)

        Unknown Tags
        - It is common for either the key or the value to be the input elements.
        In this case, the utility method
        java.util.function.Function.identity() may be helpful.
        For example, the following produces a `Map` mapping
        students to their grade point average:
        ````Map<Student, Double> studentToGPA
          = students.stream().collect(
            toMap(Function.identity(),
                  student -> computeGPA(student)));````
        And the following produces a `Map` mapping a unique identifier to
        students:
        ````Map<String, Student> studentIdToStudent
          = students.stream().collect(
            toMap(Student::getId,
                  Function.identity()));````
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If it is
        not required that results are inserted into the `Map` in encounter
        order, using .toConcurrentMap(Function, Function)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def toUnmodifiableMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"]) -> "Collector"["T", Any, dict["K", "U"]]:
        """
        Returns a `Collector` that accumulates the input elements into an
        <a href="../Map.html#unmodifiable">unmodifiable Map</a>,
        whose keys and values are the result of applying the provided
        mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to
        Object.equals(Object)), an `IllegalStateException` is
        thrown when the collection operation is performed.  If the mapped keys
        might have duplicates, use .toUnmodifiableMap(Function, Function, BinaryOperator)
        to handle merging of the values.
        
        The returned Collector disallows null keys and values. If either mapping function
        returns null, `NullPointerException` will be thrown.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: a mapping function to produce keys, must be non-null
        - valueMapper: a mapping function to produce values, must be non-null

        Returns
        - a `Collector` that accumulates the input elements into an
        <a href="../Map.html#unmodifiable">unmodifiable Map</a>, whose keys and values
        are the result of applying the provided mapping functions to the input elements

        Raises
        - NullPointerException: if either keyMapper or valueMapper is null

        See
        - .toUnmodifiableMap(Function, Function, BinaryOperator)

        Since
        - 10
        """
        ...


    @staticmethod
    def toMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"], mergeFunction: "BinaryOperator"["U"]) -> "Collector"["T", Any, dict["K", "U"]]:
        """
        Returns a `Collector` that accumulates elements into a
        `Map` whose keys and values are the result of applying the provided
        mapping functions to the input elements.
        
        If the mapped
        keys contain duplicates (according to Object.equals(Object)),
        the value mapping function is applied to each equal element, and the
        results are merged using the provided merging function.
        
        There are no guarantees on the type, mutability, serializability,
        or thread-safety of the `Map` returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: a mapping function to produce keys
        - valueMapper: a mapping function to produce values
        - mergeFunction: a merge function, used to resolve collisions between
                             values associated with the same key, as supplied
                             to Map.merge(Object, Object, BiFunction)

        Returns
        - a `Collector` which collects elements into a `Map`
        whose keys are the result of applying a key mapping function to the input
        elements, and whose values are the result of applying a value mapping
        function to all input elements equal to the key and combining them
        using the merge function

        See
        - .toConcurrentMap(Function, Function, BinaryOperator)

        Unknown Tags
        - There are multiple ways to deal with collisions between multiple elements
        mapping to the same key.  The other forms of `toMap` simply use
        a merge function that throws unconditionally, but you can easily write
        more flexible merge policies.  For example, if you have a stream
        of `Person`, and you want to produce a "phone book" mapping name to
        address, but it is possible that two persons have the same name, you can
        do as follows to gracefully deal with these collisions, and produce a
        `Map` mapping names to a concatenated list of addresses:
        ````Map<String, String> phoneBook
          = people.stream().collect(
            toMap(Person::getName,
                  Person::getAddress,
                  (s, a) -> s + ", " + a));````
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If it is
        not required that results are merged into the `Map` in encounter
        order, using .toConcurrentMap(Function, Function, BinaryOperator)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def toUnmodifiableMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"], mergeFunction: "BinaryOperator"["U"]) -> "Collector"["T", Any, dict["K", "U"]]:
        """
        Returns a `Collector` that accumulates the input elements into an
        <a href="../Map.html#unmodifiable">unmodifiable Map</a>,
        whose keys and values are the result of applying the provided
        mapping functions to the input elements.
        
        If the mapped
        keys contain duplicates (according to Object.equals(Object)),
        the value mapping function is applied to each equal element, and the
        results are merged using the provided merging function.
        
        The returned Collector disallows null keys and values. If either mapping function
        returns null, `NullPointerException` will be thrown.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: a mapping function to produce keys, must be non-null
        - valueMapper: a mapping function to produce values, must be non-null
        - mergeFunction: a merge function, used to resolve collisions between
                             values associated with the same key, as supplied
                             to Map.merge(Object, Object, BiFunction),
                             must be non-null

        Returns
        - a `Collector` that accumulates the input elements into an
        <a href="../Map.html#unmodifiable">unmodifiable Map</a>, whose keys and values
        are the result of applying the provided mapping functions to the input elements

        Raises
        - NullPointerException: if the keyMapper, valueMapper, or mergeFunction is null

        See
        - .toUnmodifiableMap(Function, Function)

        Since
        - 10
        """
        ...


    @staticmethod
    def toMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"], mergeFunction: "BinaryOperator"["U"], mapFactory: "Supplier"["M"]) -> "Collector"["T", Any, "M"]:
        """
        Returns a `Collector` that accumulates elements into a
        `Map` whose keys and values are the result of applying the provided
        mapping functions to the input elements.
        
        If the mapped
        keys contain duplicates (according to Object.equals(Object)),
        the value mapping function is applied to each equal element, and the
        results are merged using the provided merging function.  The `Map`
        is created by a provided supplier function.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function
        
        Type `<M>`: the type of the resulting `Map`

        Arguments
        - keyMapper: a mapping function to produce keys
        - valueMapper: a mapping function to produce values
        - mergeFunction: a merge function, used to resolve collisions between
                             values associated with the same key, as supplied
                             to Map.merge(Object, Object, BiFunction)
        - mapFactory: a supplier providing a new empty `Map`
                          into which the results will be inserted

        Returns
        - a `Collector` which collects elements into a `Map`
        whose keys are the result of applying a key mapping function to the input
        elements, and whose values are the result of applying a value mapping
        function to all input elements equal to the key and combining them
        using the merge function

        See
        - .toConcurrentMap(Function, Function, BinaryOperator, Supplier)

        Unknown Tags
        - The returned `Collector` is not concurrent.  For parallel stream
        pipelines, the `combiner` function operates by merging the keys
        from one map into another, which can be an expensive operation.  If it is
        not required that results are merged into the `Map` in encounter
        order, using .toConcurrentMap(Function, Function, BinaryOperator, Supplier)
        may offer better parallel performance.
        """
        ...


    @staticmethod
    def toConcurrentMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"]) -> "Collector"["T", Any, "ConcurrentMap"["K", "U"]]:
        """
        Returns a concurrent `Collector` that accumulates elements into a
        `ConcurrentMap` whose keys and values are the result of applying
        the provided mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to
        Object.equals(Object)), an `IllegalStateException` is
        thrown when the collection operation is performed.  If the mapped keys
        may have duplicates, use
        .toConcurrentMap(Function, Function, BinaryOperator) instead.
        
        There are no guarantees on the type, mutability, or serializability
        of the `ConcurrentMap` returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: the mapping function to produce keys
        - valueMapper: the mapping function to produce values

        Returns
        - a concurrent, unordered `Collector` which collects elements into a
        `ConcurrentMap` whose keys are the result of applying a key mapping
        function to the input elements, and whose values are the result of
        applying a value mapping function to the input elements

        See
        - .toConcurrentMap(Function, Function, BinaryOperator, Supplier)

        Unknown Tags
        - It is common for either the key or the value to be the input elements.
        In this case, the utility method
        java.util.function.Function.identity() may be helpful.
        For example, the following produces a `ConcurrentMap` mapping
        students to their grade point average:
        ````ConcurrentMap<Student, Double> studentToGPA
          = students.stream().collect(
            toConcurrentMap(Function.identity(),
                            student -> computeGPA(student)));````
        And the following produces a `ConcurrentMap` mapping a
        unique identifier to students:
        ````ConcurrentMap<String, Student> studentIdToStudent
          = students.stream().collect(
            toConcurrentMap(Student::getId,
                            Function.identity()));````
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        """
        ...


    @staticmethod
    def toConcurrentMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"], mergeFunction: "BinaryOperator"["U"]) -> "Collector"["T", Any, "ConcurrentMap"["K", "U"]]:
        """
        Returns a concurrent `Collector` that accumulates elements into a
        `ConcurrentMap` whose keys and values are the result of applying
        the provided mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to Object.equals(Object)),
        the value mapping function is applied to each equal element, and the
        results are merged using the provided merging function.
        
        There are no guarantees on the type, mutability, or serializability
        of the `ConcurrentMap` returned.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function

        Arguments
        - keyMapper: a mapping function to produce keys
        - valueMapper: a mapping function to produce values
        - mergeFunction: a merge function, used to resolve collisions between
                             values associated with the same key, as supplied
                             to Map.merge(Object, Object, BiFunction)

        Returns
        - a concurrent, unordered `Collector` which collects elements into a
        `ConcurrentMap` whose keys are the result of applying a key mapping
        function to the input elements, and whose values are the result of
        applying a value mapping function to all input elements equal to the key
        and combining them using the merge function

        See
        - .toMap(Function, Function, BinaryOperator)

        Unknown Tags
        - There are multiple ways to deal with collisions between multiple elements
        mapping to the same key.  The other forms of `toConcurrentMap` simply use
        a merge function that throws unconditionally, but you can easily write
        more flexible merge policies.  For example, if you have a stream
        of `Person`, and you want to produce a "phone book" mapping name to
        address, but it is possible that two persons have the same name, you can
        do as follows to gracefully deal with these collisions, and produce a
        `ConcurrentMap` mapping names to a concatenated list of addresses:
        ````ConcurrentMap<String, String> phoneBook
          = people.stream().collect(
            toConcurrentMap(Person::getName,
                            Person::getAddress,
                            (s, a) -> s + ", " + a));````
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        """
        ...


    @staticmethod
    def toConcurrentMap(keyMapper: "Function"["T", "K"], valueMapper: "Function"["T", "U"], mergeFunction: "BinaryOperator"["U"], mapFactory: "Supplier"["M"]) -> "Collector"["T", Any, "M"]:
        """
        Returns a concurrent `Collector` that accumulates elements into a
        `ConcurrentMap` whose keys and values are the result of applying
        the provided mapping functions to the input elements.
        
        If the mapped keys contain duplicates (according to Object.equals(Object)),
        the value mapping function is applied to each equal element, and the
        results are merged using the provided merging function.  The
        `ConcurrentMap` is created by a provided supplier function.
        
        This is a Collector.Characteristics.CONCURRENT concurrent and
        Collector.Characteristics.UNORDERED unordered Collector.
        
        Type `<T>`: the type of the input elements
        
        Type `<K>`: the output type of the key mapping function
        
        Type `<U>`: the output type of the value mapping function
        
        Type `<M>`: the type of the resulting `ConcurrentMap`

        Arguments
        - keyMapper: a mapping function to produce keys
        - valueMapper: a mapping function to produce values
        - mergeFunction: a merge function, used to resolve collisions between
                             values associated with the same key, as supplied
                             to Map.merge(Object, Object, BiFunction)
        - mapFactory: a supplier providing a new empty `ConcurrentMap`
                          into which the results will be inserted

        Returns
        - a concurrent, unordered `Collector` which collects elements into a
        `ConcurrentMap` whose keys are the result of applying a key mapping
        function to the input elements, and whose values are the result of
        applying a value mapping function to all input elements equal to the key
        and combining them using the merge function

        See
        - .toMap(Function, Function, BinaryOperator, Supplier)
        """
        ...


    @staticmethod
    def summarizingInt(mapper: "ToIntFunction"["T"]) -> "Collector"["T", Any, "IntSummaryStatistics"]:
        """
        Returns a `Collector` which applies an `int`-producing
        mapping function to each input element, and returns summary statistics
        for the resulting values.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a mapping function to apply to each element

        Returns
        - a `Collector` implementing the summary-statistics reduction

        See
        - .summarizingLong(ToLongFunction)
        """
        ...


    @staticmethod
    def summarizingLong(mapper: "ToLongFunction"["T"]) -> "Collector"["T", Any, "LongSummaryStatistics"]:
        """
        Returns a `Collector` which applies an `long`-producing
        mapping function to each input element, and returns summary statistics
        for the resulting values.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: the mapping function to apply to each element

        Returns
        - a `Collector` implementing the summary-statistics reduction

        See
        - .summarizingInt(ToIntFunction)
        """
        ...


    @staticmethod
    def summarizingDouble(mapper: "ToDoubleFunction"["T"]) -> "Collector"["T", Any, "DoubleSummaryStatistics"]:
        """
        Returns a `Collector` which applies an `double`-producing
        mapping function to each input element, and returns summary statistics
        for the resulting values.
        
        Type `<T>`: the type of the input elements

        Arguments
        - mapper: a mapping function to apply to each element

        Returns
        - a `Collector` implementing the summary-statistics reduction

        See
        - .summarizingInt(ToIntFunction)
        """
        ...


    @staticmethod
    def teeing(downstream1: "Collector"["T", Any, "R1"], downstream2: "Collector"["T", Any, "R2"], merger: "BiFunction"["R1", "R2", "R"]) -> "Collector"["T", Any, "R"]:
        """
        Returns a `Collector` that is a composite of two downstream collectors.
        Every element passed to the resulting collector is processed by both downstream
        collectors, then their results are merged using the specified merge function
        into the final result.
        
        The resulting collector functions do the following:
        
        
        - supplier: creates a result container that contains result containers
        obtained by calling each collector's supplier
        - accumulator: calls each collector's accumulator with its result container
        and the input element
        - combiner: calls each collector's combiner with two result containers
        - finisher: calls each collector's finisher with its result container,
        then calls the supplied merger and returns its result.
        
        
        The resulting collector is Collector.Characteristics.UNORDERED if both downstream
        collectors are unordered and Collector.Characteristics.CONCURRENT if both downstream
        collectors are concurrent.
        
        Type `<T>`: the type of the input elements
        
        Type `<R>`: the final result type

        Arguments
        - <R1>: the result type of the first collector
        - <R2>: the result type of the second collector
        - downstream1: the first downstream collector
        - downstream2: the second downstream collector
        - merger: the function which merges two results into the single one

        Returns
        - a `Collector` which aggregates the results of two supplied collectors.

        Since
        - 12
        """
        ...



from .ServerLinks import ServerLinks
from .GameRule import GameRule
from .CropState import CropState
from .Particle import Particle
from .Keyed import Keyed
from .Color import Color
from .Effect import Effect
from .JukeboxSong import JukeboxSong
from .NamespacedKey import NamespacedKey
from .WorldType import WorldType
from .Vibration import Vibration
from .SandstoneType import SandstoneType
from .UnsafeValues import UnsafeValues
from .HeightMap import HeightMap
from .Art import Art
from .SoundGroup import SoundGroup
from .GameMode import GameMode
from .BanList import BanList
from .Axis import Axis
from .BanEntry import BanEntry
from .FireworkEffect import FireworkEffect
from .Note import Note
from .ExplosionResult import ExplosionResult
from .GrassSpecies import GrassSpecies
from .RegionAccessor import RegionAccessor
from .Chunk import Chunk
from .Statistic import Statistic
from .WeatherType import WeatherType
from .Translatable import Translatable
from .TreeType import TreeType
from .Sound import Sound
from .CoalType import CoalType
from .DyeColor import DyeColor
from .ServerTickManager import ServerTickManager
from .ChunkSnapshot import ChunkSnapshot
from .FeatureFlag import FeatureFlag
from .Server import Server
from .SkullType import SkullType
from .Tag import Tag
from .Fluid import Fluid
from .WorldBorder import WorldBorder
from .Bukkit import Bukkit
from .StructureType import StructureType
from .Instrument import Instrument
from .Rotation import Rotation
from .PortalType import PortalType
from .Nameable import Nameable
from .Warning import Warning
from .Material import Material
from .ChatColor import ChatColor
from .SoundCategory import SoundCategory
from .Difficulty import Difficulty
from .BlockChangeDelegate import BlockChangeDelegate
from .TreeSpecies import TreeSpecies
from .Registry import Registry
from .Raid import Raid
from .World import World
from .GameEvent import GameEvent
from .OfflinePlayer import OfflinePlayer
from .MinecraftExperimental import MinecraftExperimental
from .Utility import Utility
from .NetherWartsState import NetherWartsState
from .Input import Input
from .UndefinedNullability import UndefinedNullability
from .MusicInstrument import MusicInstrument
from .WorldCreator import WorldCreator
from .Location import Location
from .FluidCollisionMode import FluidCollisionMode
from .EntityEffect import EntityEffect


"""
Python module generated from Java source file org.bukkit.event.entity.CreeperPowerEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Creeper
from org.bukkit.entity import LightningStrike
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class CreeperPowerEvent(EntityEvent, Cancellable):
    """
    Called when a Creeper is struck by lightning.
    
    If a Creeper Power event is cancelled, the Creeper will not be powered.
    """

    def __init__(self, creeper: "Creeper", bolt: "LightningStrike", cause: "PowerCause"):
        ...


    def __init__(self, creeper: "Creeper", cause: "PowerCause"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Creeper":
        ...


    def getLightning(self) -> "LightningStrike":
        """
        Gets the lightning bolt which is striking the Creeper.

        Returns
        - The Entity for the lightning bolt which is striking the Creeper
        """
        ...


    def getCause(self) -> "PowerCause":
        """
        Gets the cause of the creeper being (un)powered.

        Returns
        - A PowerCause value detailing the cause of change in power.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class PowerCause(Enum):
        """
        An enum to specify the cause of the change in power
        """

        LIGHTNING = 0
        """
        Power change caused by a lightning bolt
        
        Powered state: True
        """
        SET_ON = 1
        """
        Power change caused by something else (probably a plugin)
        
        Powered state: True
        """
        SET_OFF = 2
        """
        Power change caused by something else (probably a plugin)
        
        Powered state: False
        """



"""
Python module generated from Java source file com.google.gson.internal.bind.ArrayTypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal import $Gson$Types
from com.google.gson.internal.bind import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.lang.reflect import Array
from java.lang.reflect import GenericArrayType
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class ArrayTypeAdapter(TypeAdapter):
    """
    Adapt an array of objects.
    """

    FACTORY = TypeAdapterFactory() {
    
        @Override
        public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> typeToken) {
            Type type = typeToken.getType();
            if (!(type instanceof GenericArrayType || (type instanceof Class && ((Class<?>) type).isArray()))) {
                return null;
            }
            Type componentType = $Gson$Types.getArrayComponentType(type);
            TypeAdapter<?> componentTypeAdapter = gson.getAdapter(TypeToken.get(componentType));
            @SuppressWarnings({ "unchecked", "rawtypes" })
            TypeAdapter<T> arrayAdapter = ArrayTypeAdapter(gson, componentTypeAdapter, $Gson$Types.getRawType(componentType));
            return arrayAdapter;
        }
    }


    def __init__(self, context: "Gson", componentTypeAdapter: "TypeAdapter"["E"], componentType: type["E"]):
        ...


    def read(self, in: "JsonReader") -> "Object":
        ...


    def write(self, out: "JsonWriter", array: "Object") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.plugin.RegisteredServiceProvider

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class RegisteredServiceProvider(Comparable):
    """
    A registered service provider.
    
    Type `<T>`: Service
    """

    def __init__(self, service: type["T"], provider: "T", priority: "ServicePriority", plugin: "Plugin"):
        ...


    def getService(self) -> type["T"]:
        ...


    def getPlugin(self) -> "Plugin":
        ...


    def getProvider(self) -> "T":
        ...


    def getPriority(self) -> "ServicePriority":
        ...


    def compareTo(self, other: "RegisteredServiceProvider"[Any]) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerRecipeBookSettingsChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerRecipeBookSettingsChangeEvent(PlayerEvent):
    """
    Called when a player changes recipe book settings.
    """

    def __init__(self, player: "Player", recipeBookType: "RecipeBookType", open: bool, filtering: bool):
        ...


    def getRecipeBookType(self) -> "RecipeBookType":
        """
        Gets the type of recipe book the player is changing the settings for.

        Returns
        - the type of recipe book
        """
        ...


    def isOpen(self) -> bool:
        """
        Checks if the recipe book is being opened or closed.

        Returns
        - True if opening
        """
        ...


    def isFiltering(self) -> bool:
        """
        Checks if the recipe book filter is being enabled or disabled.

        Returns
        - True if enabling
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class RecipeBookType(Enum):
        """
        Enum representing the various types of recipe book.
        
        Different types of recipe book are shown in different GUIs.
        """

        CRAFTING = 0
        """
        Recipe book seen in crafting table and player inventory.
        """
        FURNACE = 1
        """
        Recipe book seen in furnace.
        """
        BLAST_FURNACE = 2
        """
        Recipe book seen in blast furnace.
        """
        SMOKER = 3
        """
        Recipe book seen in smoker.
        """



"""
Python module generated from Java source file org.bukkit.event.entity.EntityEnterLoveModeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Animals
from org.bukkit.entity import HumanEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityEnterLoveModeEvent(EntityEvent, Cancellable):
    """
    Called when an entity enters love mode.
    
    This can be cancelled but the item will still be consumed that was used to
    make the entity enter into love mode.
    """

    def __init__(self, animalInLove: "Animals", humanEntity: "HumanEntity", ticksInLove: int):
        ...


    def getEntity(self) -> "Animals":
        """
        Gets the animal that is entering love mode.

        Returns
        - The animal that is entering love mode
        """
        ...


    def getHumanEntity(self) -> "HumanEntity":
        """
        Gets the Human Entity that caused the animal to enter love mode.

        Returns
        - The Human entity that caused the animal to enter love mode, or
        null if there wasn't one.
        """
        ...


    def getTicksInLove(self) -> int:
        """
        Gets the amount of ticks that the animal will fall in love for.

        Returns
        - The amount of ticks that the animal will fall in love for
        """
        ...


    def setTicksInLove(self, ticksInLove: int) -> None:
        """
        Sets the amount of ticks that the animal will fall in love for.

        Arguments
        - ticksInLove: The amount of ticks that the animal will fall in love
        for
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.Campfire

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.inventory import Inventory
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class Campfire(TileState):
    """
    Represents a captured state of a campfire.
    """

    def getSize(self) -> int:
        """
        Returns
        - The size of the inventory

        See
        - Inventory.getSize()
        """
        ...


    def getItem(self, index: int) -> "ItemStack":
        """
        Arguments
        - index: The index of the Slot's ItemStack to return

        Returns
        - The ItemStack in the slot

        See
        - Inventory.getItem(int)
        """
        ...


    def setItem(self, index: int, item: "ItemStack") -> None:
        """
        Arguments
        - index: The index where to put the ItemStack
        - item: The ItemStack to set

        See
        - Inventory.setItem(int, org.bukkit.inventory.ItemStack)
        """
        ...


    def getCookTime(self, index: int) -> int:
        """
        Get cook time.
        
        This is the amount of time the item has been cooking for.

        Arguments
        - index: item slot index

        Returns
        - Cook time
        """
        ...


    def setCookTime(self, index: int, cookTime: int) -> None:
        """
        Set cook time.
        
        This is the amount of time the item has been cooking for.

        Arguments
        - index: item slot index
        - cookTime: Cook time
        """
        ...


    def getCookTimeTotal(self, index: int) -> int:
        """
        Get cook time total.
        
        This is the amount of time the item is required to cook for.

        Arguments
        - index: item slot index

        Returns
        - Cook time total
        """
        ...


    def setCookTimeTotal(self, index: int, cookTimeTotal: int) -> None:
        """
        Set cook time.
        
        This is the amount of time the item is required to cook for.

        Arguments
        - index: item slot index
        - cookTimeTotal: Cook time total
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.chat.TranslationRegistry

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonElement
from com.google.gson import JsonObject
from java.io import IOException
from java.io import InputStreamReader
from java.nio.charset import StandardCharsets
from java.util import ResourceBundle
from net.md_5.bungee.chat import *
from typing import Any, Callable, Iterable, Tuple


class TranslationRegistry:

    INSTANCE = TranslationRegistry()


    def translate(self, s: str) -> str:
        ...



"""
Python module generated from Java source file java.util.AbstractQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class AbstractQueue(AbstractCollection, Queue):
    """
    This class provides skeletal implementations of some Queue
    operations. The implementations in this class are appropriate when
    the base implementation does *not* allow `null`
    elements.  Methods .add add, .remove remove, and
    .element element are based on .offer offer, .poll poll, and .peek peek, respectively, but throw
    exceptions instead of indicating failure via `False` or
    `null` returns.
    
    A `Queue` implementation that extends this class must
    minimally define a method Queue.offer which does not permit
    insertion of `null` elements, along with methods Queue.peek, Queue.poll, Collection.size, and
    Collection.iterator.  Typically, additional methods will be
    overridden as well.  If these requirements cannot be met, consider
    instead subclassing AbstractCollection.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def add(self, e: "E") -> bool:
        """
        Inserts the specified element into this queue if it is possible to do so
        immediately without violating capacity restrictions, returning
        `True` upon success and throwing an `IllegalStateException`
        if no space is currently available.
        
        This implementation returns `True` if `offer` succeeds,
        else throws an `IllegalStateException`.

        Arguments
        - e: the element to add

        Returns
        - `True` (as specified by Collection.add)

        Raises
        - IllegalStateException: if the element cannot be added at this
                time due to capacity restrictions
        - ClassCastException: if the class of the specified element
                prevents it from being added to this queue
        - NullPointerException: if the specified element is null and
                this queue does not permit null elements
        - IllegalArgumentException: if some property of this element
                prevents it from being added to this queue
        """
        ...


    def remove(self) -> "E":
        """
        Retrieves and removes the head of this queue.  This method differs
        from .poll poll only in that it throws an exception if this
        queue is empty.
        
        This implementation returns the result of `poll`
        unless the queue is empty.

        Returns
        - the head of this queue

        Raises
        - NoSuchElementException: if this queue is empty
        """
        ...


    def element(self) -> "E":
        """
        Retrieves, but does not remove, the head of this queue.  This method
        differs from .peek peek only in that it throws an exception if
        this queue is empty.
        
        This implementation returns the result of `peek`
        unless the queue is empty.

        Returns
        - the head of this queue

        Raises
        - NoSuchElementException: if this queue is empty
        """
        ...


    def clear(self) -> None:
        """
        Removes all of the elements from this queue.
        The queue will be empty after this call returns.
        
        This implementation repeatedly invokes .poll poll until it
        returns `null`.
        """
        ...


    def addAll(self, c: Iterable["E"]) -> bool:
        """
        Adds all of the elements in the specified collection to this
        queue.  Attempts to addAll of a queue to itself result in
        `IllegalArgumentException`. Further, the behavior of
        this operation is undefined if the specified collection is
        modified while the operation is in progress.
        
        This implementation iterates over the specified collection,
        and adds each element returned by the iterator to this
        queue, in turn.  A runtime exception encountered while
        trying to add an element (including, in particular, a
        `null` element) may result in only some of the elements
        having been successfully added when the associated exception is
        thrown.

        Arguments
        - c: collection containing elements to be added to this queue

        Returns
        - `True` if this queue changed as a result of the call

        Raises
        - ClassCastException: if the class of an element of the specified
                collection prevents it from being added to this queue
        - NullPointerException: if the specified collection contains a
                null element and this queue does not permit null elements,
                or if the specified collection is null
        - IllegalArgumentException: if some property of an element of the
                specified collection prevents it from being added to this
                queue, or if the specified collection is this queue
        - IllegalStateException: if not all the elements can be added at
                this time due to insertion restrictions

        See
        - .add(Object)
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.Uninterruptibles

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.time import Duration
from java.util.concurrent import BlockingQueue
from java.util.concurrent import CancellationException
from java.util.concurrent import CountDownLatch
from java.util.concurrent import ExecutionException
from java.util.concurrent import ExecutorService
from java.util.concurrent import Future
from java.util.concurrent import Semaphore
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import Lock
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Uninterruptibles:
    """
    Utilities for treating interruptible operations as uninterruptible. In all cases, if a thread is
    interrupted during such a call, the call continues to block until the result is available or the
    timeout elapses, and only then re-interrupts the thread.

    Author(s)
    - Anthony Zana

    Since
    - 10.0
    """

    @staticmethod
    def awaitUninterruptibly(latch: "CountDownLatch") -> None:
        """
        Invokes `latch.`CountDownLatch.await() await() uninterruptibly.
        """
        ...


    @staticmethod
    def awaitUninterruptibly(latch: "CountDownLatch", timeout: "Duration") -> bool:
        """
        Invokes `latch.`CountDownLatch.await(long, TimeUnit) await(timeout, unit)
        uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def awaitUninterruptibly(latch: "CountDownLatch", timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `latch.`CountDownLatch.await(long, TimeUnit) await(timeout, unit)
        uninterruptibly.
        """
        ...


    @staticmethod
    def awaitUninterruptibly(condition: "Condition", timeout: "Duration") -> bool:
        """
        Invokes `condition.`Condition.await(long, TimeUnit) await(timeout, unit)
        uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def awaitUninterruptibly(condition: "Condition", timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `condition.`Condition.await(long, TimeUnit) await(timeout, unit)
        uninterruptibly.

        Since
        - 23.6
        """
        ...


    @staticmethod
    def joinUninterruptibly(toJoin: "Thread") -> None:
        """
        Invokes `toJoin.`Thread.join() join() uninterruptibly.
        """
        ...


    @staticmethod
    def joinUninterruptibly(toJoin: "Thread", timeout: "Duration") -> None:
        """
        Invokes `unit.`TimeUnit.timedJoin(Thread, long) timedJoin(toJoin, timeout)
        uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def joinUninterruptibly(toJoin: "Thread", timeout: int, unit: "TimeUnit") -> None:
        """
        Invokes `unit.`TimeUnit.timedJoin(Thread, long) timedJoin(toJoin, timeout)
        uninterruptibly.
        """
        ...


    @staticmethod
    def getUninterruptibly(future: "Future"["V"]) -> "V":
        """
        Invokes `future.`Future.get() get() uninterruptibly.
        
        Similar methods:
        
        
          - To retrieve a result from a `Future` that is already done, use Futures.getDone Futures.getDone.
          - To treat InterruptedException uniformly with other exceptions, use Futures.getChecked(Future, Class) Futures.getChecked.
          - To get uninterruptibility and remove checked exceptions, use Futures.getUnchecked.

        Raises
        - ExecutionException: if the computation threw an exception
        - CancellationException: if the computation was cancelled
        """
        ...


    @staticmethod
    def getUninterruptibly(future: "Future"["V"], timeout: "Duration") -> "V":
        """
        Invokes `future.`Future.get(long, TimeUnit) get(timeout, unit) uninterruptibly.
        
        Similar methods:
        
        
          - To retrieve a result from a `Future` that is already done, use Futures.getDone Futures.getDone.
          - To treat InterruptedException uniformly with other exceptions, use Futures.getChecked(Future, Class, long, TimeUnit) Futures.getChecked.
          - To get uninterruptibility and remove checked exceptions, use Futures.getUnchecked.

        Raises
        - ExecutionException: if the computation threw an exception
        - CancellationException: if the computation was cancelled
        - TimeoutException: if the wait timed out

        Since
        - 28.0
        """
        ...


    @staticmethod
    def getUninterruptibly(future: "Future"["V"], timeout: int, unit: "TimeUnit") -> "V":
        """
        Invokes `future.`Future.get(long, TimeUnit) get(timeout, unit) uninterruptibly.
        
        Similar methods:
        
        
          - To retrieve a result from a `Future` that is already done, use Futures.getDone Futures.getDone.
          - To treat InterruptedException uniformly with other exceptions, use Futures.getChecked(Future, Class, long, TimeUnit) Futures.getChecked.
          - To get uninterruptibility and remove checked exceptions, use Futures.getUnchecked.

        Raises
        - ExecutionException: if the computation threw an exception
        - CancellationException: if the computation was cancelled
        - TimeoutException: if the wait timed out
        """
        ...


    @staticmethod
    def takeUninterruptibly(queue: "BlockingQueue"["E"]) -> "E":
        """
        Invokes `queue.`BlockingQueue.take() take() uninterruptibly.
        """
        ...


    @staticmethod
    def putUninterruptibly(queue: "BlockingQueue"["E"], element: "E") -> None:
        """
        Invokes `queue.`BlockingQueue.put(Object) put(element) uninterruptibly.

        Raises
        - ClassCastException: if the class of the specified element prevents it from being added
            to the given queue
        - IllegalArgumentException: if some property of the specified element prevents it from
            being added to the given queue
        """
        ...


    @staticmethod
    def sleepUninterruptibly(sleepFor: "Duration") -> None:
        """
        Invokes `unit.`TimeUnit.sleep(long) sleep(sleepFor) uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def sleepUninterruptibly(sleepFor: int, unit: "TimeUnit") -> None:
        """
        Invokes `unit.`TimeUnit.sleep(long) sleep(sleepFor) uninterruptibly.
        """
        ...


    @staticmethod
    def tryAcquireUninterruptibly(semaphore: "Semaphore", timeout: "Duration") -> bool:
        """
        Invokes `semaphore.`Semaphore.tryAcquire(int, long, TimeUnit) tryAcquire(1,
        timeout, unit) uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def tryAcquireUninterruptibly(semaphore: "Semaphore", timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `semaphore.`Semaphore.tryAcquire(int, long, TimeUnit) tryAcquire(1,
        timeout, unit) uninterruptibly.

        Since
        - 18.0
        """
        ...


    @staticmethod
    def tryAcquireUninterruptibly(semaphore: "Semaphore", permits: int, timeout: "Duration") -> bool:
        """
        Invokes `semaphore.`Semaphore.tryAcquire(int, long, TimeUnit) tryAcquire(permits,
        timeout, unit) uninterruptibly.

        Since
        - 28.0
        """
        ...


    @staticmethod
    def tryAcquireUninterruptibly(semaphore: "Semaphore", permits: int, timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `semaphore.`Semaphore.tryAcquire(int, long, TimeUnit) tryAcquire(permits,
        timeout, unit) uninterruptibly.

        Since
        - 18.0
        """
        ...


    @staticmethod
    def tryLockUninterruptibly(lock: "Lock", timeout: "Duration") -> bool:
        """
        Invokes `lock.`Lock.tryLock(long, TimeUnit) tryLock(timeout, unit)
        uninterruptibly.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def tryLockUninterruptibly(lock: "Lock", timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `lock.`Lock.tryLock(long, TimeUnit) tryLock(timeout, unit)
        uninterruptibly.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def awaitTerminationUninterruptibly(executor: "ExecutorService") -> None:
        """
        Invokes `executor.`ExecutorService.awaitTermination(long, TimeUnit)
        awaitTermination(long, TimeUnit) uninterruptibly with no timeout.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def awaitTerminationUninterruptibly(executor: "ExecutorService", timeout: "Duration") -> bool:
        """
        Invokes `executor.`ExecutorService.awaitTermination(long, TimeUnit)
        awaitTermination(long, TimeUnit) uninterruptibly.

        Since
        - 30.0
        """
        ...


    @staticmethod
    def awaitTerminationUninterruptibly(executor: "ExecutorService", timeout: int, unit: "TimeUnit") -> bool:
        """
        Invokes `executor.`ExecutorService.awaitTermination(long, TimeUnit)
        awaitTermination(long, TimeUnit) uninterruptibly.

        Since
        - 30.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Creeper

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Creeper(Monster):
    """
    Represents a Creeper
    """

    def isPowered(self) -> bool:
        """
        Checks if this Creeper is powered (Electrocuted)

        Returns
        - True if this creeper is powered
        """
        ...


    def setPowered(self, value: bool) -> None:
        """
        Sets the Powered status of this Creeper

        Arguments
        - value: New Powered status
        """
        ...


    def setMaxFuseTicks(self, ticks: int) -> None:
        """
        Set the maximum fuse ticks for this Creeper, where the maximum ticks
        is the amount of time in which a creeper is allowed to be in the
        primed state before exploding.

        Arguments
        - ticks: the new maximum fuse ticks
        """
        ...


    def getMaxFuseTicks(self) -> int:
        """
        Get the maximum fuse ticks for this Creeper, where the maximum ticks
        is the amount of time in which a creeper is allowed to be in the
        primed state before exploding.

        Returns
        - the maximum fuse ticks
        """
        ...


    def setFuseTicks(self, ticks: int) -> None:
        """
        Set the fuse ticks for this Creeper, where the ticks is the amount of
        time in which a creeper has been in the primed state.

        Arguments
        - ticks: the new fuse ticks
        """
        ...


    def getFuseTicks(self) -> int:
        """
        Get the maximum fuse ticks for this Creeper, where the ticks is the
        amount of time in which a creeper has been in the primed state.

        Returns
        - the fuse ticks
        """
        ...


    def setExplosionRadius(self, radius: int) -> None:
        """
        Set the explosion radius in which this Creeper's explosion will affect.

        Arguments
        - radius: the new explosion radius
        """
        ...


    def getExplosionRadius(self) -> int:
        """
        Get the explosion radius in which this Creeper's explosion will affect.

        Returns
        - the explosion radius
        """
        ...


    def explode(self) -> None:
        """
        Makes this Creeper explode instantly.
        
        The resulting explosion can be cancelled by an
        org.bukkit.event.entity.ExplosionPrimeEvent and obeys the mob
        griefing gamerule.
        """
        ...


    def ignite(self, entity: "Entity") -> None:
        """
        Ignites this Creeper, beginning its fuse.
        
        The amount of time the Creeper takes to explode will depend on what
        .setMaxFuseTicks is set as.
        
        The resulting explosion can be cancelled by an
        org.bukkit.event.entity.ExplosionPrimeEvent and obeys the mob
        griefing gamerule.

        Arguments
        - entity: the entity which ignited the creeper
        """
        ...


    def ignite(self) -> None:
        """
        Ignites this Creeper, beginning its fuse.
        
        The amount of time the Creeper takes to explode will depend on what
        .setMaxFuseTicks is set as.
        
        The resulting explosion can be cancelled by an
        org.bukkit.event.entity.ExplosionPrimeEvent and obeys the mob
        griefing gamerule.
        """
        ...


    def getIgniter(self) -> "Entity":
        """
        Gets the entity which ignited the creeper, if available.

        Returns
        - the entity which ignited the creeper (if available) or null
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.AbstractSkeleton

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class AbstractSkeleton(Monster):
    """
    This interface defines or represents the abstract concept of skeleton-like
    entities on the server. The interface is hence not a direct representation
    of an entity but rather serves as a parent to interfaces/entity types like
    Skeleton, WitherSkeleton or Stray.
    
    To compute what specific type of skeleton is present in a variable/field
    of this type, instanceOf checks against the specific subtypes listed prior
    are recommended.
    """

    def getSkeletonType(self) -> "Skeleton.SkeletonType":
        """
        Gets the current type of this skeleton.

        Returns
        - Current type

        Deprecated
        - should check what class instance this is.
        """
        ...


    def setSkeletonType(self, type: "Skeleton.SkeletonType") -> None:
        """
        Arguments
        - type: type

        Deprecated
        - Must spawn a new subtype variant
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.EnchantmentStorageMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.enchantments import Enchantment
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class EnchantmentStorageMeta(ItemMeta):
    """
    EnchantmentMeta is specific to items that can *store* enchantments, as
    opposed to being enchanted. Material.ENCHANTED_BOOK is an example
    of an item with enchantment storage.
    """

    def hasStoredEnchants(self) -> bool:
        """
        Checks for the existence of any stored enchantments.

        Returns
        - True if an enchantment exists on this meta
        """
        ...


    def hasStoredEnchant(self, ench: "Enchantment") -> bool:
        """
        Checks for storage of the specified enchantment.

        Arguments
        - ench: enchantment to check

        Returns
        - True if this enchantment is stored in this meta
        """
        ...


    def getStoredEnchantLevel(self, ench: "Enchantment") -> int:
        """
        Checks for the level of the stored enchantment.

        Arguments
        - ench: enchantment to check

        Returns
        - The level that the specified stored enchantment has, or 0 if
            none
        """
        ...


    def getStoredEnchants(self) -> dict["Enchantment", "Integer"]:
        """
        Gets a copy the stored enchantments in this ItemMeta.

        Returns
        - An immutable copy of the stored enchantments
        """
        ...


    def addStoredEnchant(self, ench: "Enchantment", level: int, ignoreLevelRestriction: bool) -> bool:
        """
        Stores the specified enchantment in this item meta.

        Arguments
        - ench: Enchantment to store
        - level: Level for the enchantment
        - ignoreLevelRestriction: this indicates the enchantment should be
            applied, ignoring the level limit

        Returns
        - True if the item meta changed as a result of this call, False
            otherwise

        Raises
        - IllegalArgumentException: if enchantment is null
        """
        ...


    def removeStoredEnchant(self, ench: "Enchantment") -> bool:
        """
        Remove the specified stored enchantment from this item meta.

        Arguments
        - ench: Enchantment to remove

        Returns
        - True if the item meta changed as a result of this call, False
            otherwise

        Raises
        - IllegalArgumentException: if enchantment is null
        """
        ...


    def hasConflictingStoredEnchant(self, ench: "Enchantment") -> bool:
        """
        Checks if the specified enchantment conflicts with any enchantments in
        this ItemMeta.

        Arguments
        - ench: enchantment to test

        Returns
        - True if the enchantment conflicts, False otherwise
        """
        ...


    def clone(self) -> "EnchantmentStorageMeta":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.UncheckedTimeoutException

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class UncheckedTimeoutException(RuntimeException):
    """
    Unchecked version of java.util.concurrent.TimeoutException.

    Author(s)
    - Kevin Bourrillion

    Since
    - 1.0
    """

    def __init__(self):
        ...


    def __init__(self, message: str):
        ...


    def __init__(self, cause: "Throwable"):
        ...


    def __init__(self, message: str, cause: "Throwable"):
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.tokens.CommentToken

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from org.yaml.snakeyaml.comments import CommentType
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.tokens import *
from typing import Any, Callable, Iterable, Tuple


class CommentToken(Token):
    """
    Comment for humans
    """

    def __init__(self, type: "CommentType", value: str, startMark: "Mark", endMark: "Mark"):
        """
        Create

        Arguments
        - type: - kind
        - value: - text
        - startMark: - start
        - endMark: - end
        """
        ...


    def getCommentType(self) -> "CommentType":
        """
        getter

        Returns
        - the kind
        """
        ...


    def getValue(self) -> str:
        """
        getter

        Returns
        - text
        """
        ...


    def getTokenId(self) -> "Token.ID":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ImmediateFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from com.google.common.util.concurrent.AbstractFuture import TrustedFuture
from java.util.concurrent import ExecutionException
from java.util.concurrent import Executor
from java.util.concurrent import TimeUnit
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmediateFuture(ListenableFuture):
    """
    Implementation of Futures.immediateFuture.
    """

    def addListener(self, listener: "Runnable", executor: "Executor") -> None:
        ...


    def cancel(self, mayInterruptIfRunning: bool) -> bool:
        ...


    def get(self) -> "V":
        ...


    def get(self, timeout: int, unit: "TimeUnit") -> "V":
        ...


    def isCancelled(self) -> bool:
        ...


    def isDone(self) -> bool:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.material.Sapling

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import TreeSpecies
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Sapling(Wood):
    """
    Represents the different types of Tree block that face a direction.

    See
    - Material.LEGACY_SAPLING

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Constructs a sapling.
        """
        ...


    def __init__(self, species: "TreeSpecies"):
        """
        Constructs a sapling of the given tree species.

        Arguments
        - species: the species of the sapling
        """
        ...


    def __init__(self, species: "TreeSpecies", isInstantGrowable: bool):
        """
        Constructs a sapling of the given tree species and if is it instant
        growable

        Arguments
        - species: the species of the tree block
        - isInstantGrowable: True if the Sapling should grow when next ticked with bonemeal
        """
        ...


    def __init__(self, type: "Material"):
        """
        Constructs a sapling of the given type.

        Arguments
        - type: the type of tree block
        """
        ...


    def __init__(self, type: "Material", species: "TreeSpecies"):
        """
        Constructs a sapling of the given type and tree species.

        Arguments
        - type: the type of sapling
        - species: the species of the sapling
        """
        ...


    def __init__(self, type: "Material", species: "TreeSpecies", isInstantGrowable: bool):
        """
        Constructs a sapling of the given type and tree species and if is it
        instant growable

        Arguments
        - type: the type of sapling
        - species: the species of the sapling
        - isInstantGrowable: True if the Sapling should grow when next ticked
        with bonemeal
        """
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isInstantGrowable(self) -> bool:
        """
        Checks if the Sapling would grow when next ticked with bonemeal

        Returns
        - True if the Sapling would grow when next ticked with bonemeal
        """
        ...


    def setIsInstantGrowable(self, isInstantGrowable: bool) -> None:
        """
        Set whether this sapling will grow when next ticked with bonemeal

        Arguments
        - isInstantGrowable: True if the Sapling should grow when next ticked
        with bonemeal
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Sapling":
        ...



"""
Python module generated from Java source file java.util.IdentityHashMap

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.lang.reflect import Array
from java.util import *
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import Consumer
from jdk.internal.access import SharedSecrets
from typing import Any, Callable, Iterable, Tuple


class IdentityHashMap(AbstractMap, Map, Serializable, Cloneable):

    def __init__(self):
        """
        Constructs a new, empty identity hash map with a default expected
        maximum size (21).
        """
        ...


    def __init__(self, expectedMaxSize: int):
        """
        Constructs a new, empty map with the specified expected maximum size.
        Putting more than the expected number of key-value mappings into
        the map may cause the internal data structure to grow, which may be
        somewhat time-consuming.

        Arguments
        - expectedMaxSize: the expected maximum size of the map

        Raises
        - IllegalArgumentException: if `expectedMaxSize` is negative
        """
        ...


    def __init__(self, m: dict["K", "V"]):
        """
        Constructs a new identity hash map containing the keys-value mappings
        in the specified map.

        Arguments
        - m: the map whose mappings are to be placed into this map

        Raises
        - NullPointerException: if the specified map is null
        """
        ...


    def size(self) -> int:
        """
        Returns the number of key-value mappings in this identity hash map.

        Returns
        - the number of key-value mappings in this map
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns `True` if this identity hash map contains no key-value
        mappings.

        Returns
        - `True` if this identity hash map contains no key-value
                mappings
        """
        ...


    def get(self, key: "Object") -> "V":
        """
        Returns the value to which the specified key is mapped,
        or `null` if this map contains no mapping for the key.
        
        More formally, if this map contains a mapping from a key
        `k` to a value `v` such that `(key == k)`,
        then this method returns `v`; otherwise it returns
        `null`.  (There can be at most one such mapping.)
        
        A return value of `null` does not *necessarily*
        indicate that the map contains no mapping for the key; it's also
        possible that the map explicitly maps the key to `null`.
        The .containsKey containsKey operation may be used to
        distinguish these two cases.

        See
        - .put(Object, Object)
        """
        ...


    def containsKey(self, key: "Object") -> bool:
        """
        Tests whether the specified object reference is a key in this identity
        hash map.

        Arguments
        - key: possible key

        Returns
        - `True` if the specified object reference is a key
                 in this map

        See
        - .containsValue(Object)
        """
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Tests whether the specified object reference is a value in this identity
        hash map.

        Arguments
        - value: value whose presence in this map is to be tested

        Returns
        - `True` if this map maps one or more keys to the
                specified object reference

        See
        - .containsKey(Object)
        """
        ...


    def put(self, key: "K", value: "V") -> "V":
        """
        Associates the specified value with the specified key in this identity
        hash map.  If the map previously contained a mapping for the key, the
        old value is replaced.

        Arguments
        - key: the key with which the specified value is to be associated
        - value: the value to be associated with the specified key

        Returns
        - the previous value associated with `key`, or
                `null` if there was no mapping for `key`.
                (A `null` return can also indicate that the map
                previously associated `null` with `key`.)

        See
        - .containsKey(Object)
        """
        ...


    def putAll(self, m: dict["K", "V"]) -> None:
        """
        Copies all of the mappings from the specified map to this map.
        These mappings will replace any mappings that this map had for
        any of the keys currently in the specified map.

        Arguments
        - m: mappings to be stored in this map

        Raises
        - NullPointerException: if the specified map is null
        """
        ...


    def remove(self, key: "Object") -> "V":
        """
        Removes the mapping for this key from this map if present.

        Arguments
        - key: key whose mapping is to be removed from the map

        Returns
        - the previous value associated with `key`, or
                `null` if there was no mapping for `key`.
                (A `null` return can also indicate that the map
                previously associated `null` with `key`.)
        """
        ...


    def clear(self) -> None:
        """
        Removes all of the mappings from this map.
        The map will be empty after this call returns.
        """
        ...


    def equals(self, o: "Object") -> bool:
        """
        Compares the specified object with this map for equality.  Returns
        `True` if the given object is also a map and the two maps
        represent identical object-reference mappings.  More formally, this
        map is equal to another map `m` if and only if
        `this.entrySet().equals(m.entrySet())`.
        
        **Owing to the reference-equality-based semantics of this map it is
        possible that the symmetry and transitivity requirements of the
        `Object.equals` contract may be violated if this map is compared
        to a normal map.  However, the `Object.equals` contract is
        guaranteed to hold among `IdentityHashMap` instances.**

        Arguments
        - o: object to be compared for equality with this map

        Returns
        - `True` if the specified object is equal to this map

        See
        - Object.equals(Object)
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this map.  The hash code of a map is
        defined to be the sum of the hash codes of each entry in the map's
        `entrySet()` view.  This ensures that `m1.equals(m2)`
        implies that `m1.hashCode()==m2.hashCode()` for any two
        `IdentityHashMap` instances `m1` and `m2`, as
        required by the general contract of Object.hashCode.
        
        **Owing to the reference-equality-based semantics of the
        `Map.Entry` instances in the set returned by this map's
        `entrySet` method, it is possible that the contractual
        requirement of `Object.hashCode` mentioned in the previous
        paragraph will be violated if one of the two objects being compared is
        an `IdentityHashMap` instance and the other is a normal map.**

        Returns
        - the hash code value for this map

        See
        - .equals(Object)
        """
        ...


    def clone(self) -> "Object":
        """
        Returns a shallow copy of this identity hash map: the keys and values
        themselves are not cloned.

        Returns
        - a shallow copy of this map
        """
        ...


    def keySet(self) -> set["K"]:
        """
        Returns an identity-based set view of the keys contained in this map.
        The set is backed by the map, so changes to the map are reflected in
        the set, and vice-versa.  If the map is modified while an iteration
        over the set is in progress, the results of the iteration are
        undefined.  The set supports element removal, which removes the
        corresponding mapping from the map, via the `Iterator.remove`,
        `Set.remove`, `removeAll`, `retainAll`, and
        `clear` methods.  It does not support the `add` or
        `addAll` methods.
        
        **While the object returned by this method implements the
        `Set` interface, it does *not* obey `Set's` general
        contract.  Like its backing map, the set returned by this method
        defines element equality as reference-equality rather than
        object-equality.  This affects the behavior of its `contains`,
        `remove`, `containsAll`, `equals`, and
        `hashCode` methods.**
        
        **The `equals` method of the returned set returns `True`
        only if the specified object is a set containing exactly the same
        object references as the returned set.  The symmetry and transitivity
        requirements of the `Object.equals` contract may be violated if
        the set returned by this method is compared to a normal set.  However,
        the `Object.equals` contract is guaranteed to hold among sets
        returned by this method.**
        
        The `hashCode` method of the returned set returns the sum of
        the *identity hashcodes* of the elements in the set, rather than
        the sum of their hashcodes.  This is mandated by the change in the
        semantics of the `equals` method, in order to enforce the
        general contract of the `Object.hashCode` method among sets
        returned by this method.

        Returns
        - an identity-based set view of the keys contained in this map

        See
        - System.identityHashCode(Object)
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a Collection view of the values contained in this map.
        The collection is backed by the map, so changes to the map are
        reflected in the collection, and vice-versa.  If the map is
        modified while an iteration over the collection is in progress,
        the results of the iteration are undefined.  The collection
        supports element removal, which removes the corresponding
        mapping from the map, via the `Iterator.remove`,
        `Collection.remove`, `removeAll`,
        `retainAll` and `clear` methods.  It does not
        support the `add` or `addAll` methods.
        
        **While the object returned by this method implements the
        `Collection` interface, it does *not* obey
        `Collection's` general contract.  Like its backing map,
        the collection returned by this method defines element equality as
        reference-equality rather than object-equality.  This affects the
        behavior of its `contains`, `remove` and
        `containsAll` methods.**
        """
        ...


    def entrySet(self) -> set["Map.Entry"["K", "V"]]:
        """
        Returns a Set view of the mappings contained in this map.
        Each element in the returned set is a reference-equality-based
        `Map.Entry`.  The set is backed by the map, so changes
        to the map are reflected in the set, and vice-versa.  If the
        map is modified while an iteration over the set is in progress,
        the results of the iteration are undefined.  The set supports
        element removal, which removes the corresponding mapping from
        the map, via the `Iterator.remove`, `Set.remove`,
        `removeAll`, `retainAll` and `clear`
        methods.  It does not support the `add` or
        `addAll` methods.
        
        Like the backing map, the `Map.Entry` objects in the set
        returned by this method define key and value equality as
        reference-equality rather than object-equality.  This affects the
        behavior of the `equals` and `hashCode` methods of these
        `Map.Entry` objects.  A reference-equality based `Map.Entry
        e` is equal to an object `o` if and only if `o` is a
        `Map.Entry` and `e.getKey()==o.getKey() &&
        e.getValue()==o.getValue()`.  To accommodate these equals
        semantics, the `hashCode` method returns
        `System.identityHashCode(e.getKey()) ^
        System.identityHashCode(e.getValue())`.
        
        **Owing to the reference-equality-based semantics of the
        `Map.Entry` instances in the set returned by this method,
        it is possible that the symmetry and transitivity requirements of
        the Object.equals(Object) contract may be violated if any of
        the entries in the set is compared to a normal map entry, or if
        the set returned by this method is compared to a set of normal map
        entries (such as would be returned by a call to this method on a normal
        map).  However, the `Object.equals` contract is guaranteed to
        hold among identity-based map entries, and among sets of such entries.
        **

        Returns
        - a set view of the identity-mappings contained in this map
        """
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.scheduler.BukkitRunnable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Bukkit
from org.bukkit.plugin import Plugin
from org.bukkit.scheduler import *
from typing import Any, Callable, Iterable, Tuple


class BukkitRunnable(Runnable):
    """
    This class is provided as an easy way to handle scheduling tasks.
    """

    def isCancelled(self) -> bool:
        """
        Returns True if this task has been cancelled.

        Returns
        - True if the task has been cancelled

        Raises
        - IllegalStateException: if task was not scheduled yet
        """
        ...


    def cancel(self) -> None:
        """
        Attempts to cancel this task.

        Raises
        - IllegalStateException: if task was not scheduled yet
        """
        ...


    def runTask(self, plugin: "Plugin") -> "BukkitTask":
        """
        Schedules this in the Bukkit scheduler to run on next tick.

        Arguments
        - plugin: the reference to the plugin scheduling task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTask(Plugin, Runnable)
        """
        ...


    def runTaskAsynchronously(self, plugin: "Plugin") -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit. Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules this in the Bukkit scheduler to run asynchronously.

        Arguments
        - plugin: the reference to the plugin scheduling task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTaskAsynchronously(Plugin, Runnable)
        """
        ...


    def runTaskLater(self, plugin: "Plugin", delay: int) -> "BukkitTask":
        """
        Schedules this to run after the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTaskLater(Plugin, Runnable, long)
        """
        ...


    def runTaskLaterAsynchronously(self, plugin: "Plugin", delay: int) -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit. Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules this to run asynchronously after the specified number of
        server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTaskLaterAsynchronously(Plugin, Runnable, long)
        """
        ...


    def runTaskTimer(self, plugin: "Plugin", delay: int, period: int) -> "BukkitTask":
        """
        Schedules this to repeatedly run until cancelled, starting after the
        specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - delay: the ticks to wait before running the task
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTaskTimer(Plugin, Runnable, long, long)
        """
        ...


    def runTaskTimerAsynchronously(self, plugin: "Plugin", delay: int, period: int) -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit. Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules this to repeatedly run asynchronously until cancelled,
        starting after the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - delay: the ticks to wait before running the task for the first
            time
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalStateException: if this was already scheduled

        See
        - BukkitScheduler.runTaskTimerAsynchronously(Plugin, Runnable, long,
            long)
        """
        ...


    def getTaskId(self) -> int:
        """
        Gets the task id for this runnable.

        Returns
        - the task id that this runnable was scheduled as

        Raises
        - IllegalStateException: if task was not scheduled yet
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.messaging.PluginMessageListener

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.plugin.messaging import *
from typing import Any, Callable, Iterable, Tuple


class PluginMessageListener:
    """
    A listener for a specific Plugin Channel, which will receive notifications
    of messages sent from a client.
    """

    def onPluginMessageReceived(self, channel: str, player: "Player", message: list[int]) -> None:
        """
        A method that will be thrown when a PluginMessageSource sends a plugin
        message on a registered channel.

        Arguments
        - channel: Channel that the message was sent through.
        - player: Source of the message.
        - message: The raw message that was sent.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.ArmorStand

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from org.bukkit.inventory import EntityEquipment
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from org.bukkit.util import EulerAngle
from typing import Any, Callable, Iterable, Tuple


class ArmorStand(LivingEntity):

    def getItemInHand(self) -> "ItemStack":
        """
        Returns the item the armor stand is currently holding.

        Returns
        - the held item

        See
        - .getEquipment()

        Deprecated
        - prefer EntityEquipment.getItemInHand()
        """
        ...


    def setItemInHand(self, item: "ItemStack") -> None:
        """
        Sets the item the armor stand is currently holding.

        Arguments
        - item: the item to hold

        See
        - .getEquipment()

        Deprecated
        - prefer
        EntityEquipment.setItemInHand(org.bukkit.inventory.ItemStack)
        """
        ...


    def getBoots(self) -> "ItemStack":
        """
        Returns the item currently being worn by the armor stand on its feet.

        Returns
        - the worn item

        See
        - .getEquipment()

        Deprecated
        - prefer EntityEquipment.getBoots()
        """
        ...


    def setBoots(self, item: "ItemStack") -> None:
        """
        Sets the item currently being worn by the armor stand on its feet.

        Arguments
        - item: the item to wear

        See
        - .getEquipment()

        Deprecated
        - prefer
        EntityEquipment.setBoots(org.bukkit.inventory.ItemStack)
        """
        ...


    def getLeggings(self) -> "ItemStack":
        """
        Returns the item currently being worn by the armor stand on its legs.

        Returns
        - the worn item

        See
        - .getEquipment()

        Deprecated
        - prefer EntityEquipment.getLeggings()
        """
        ...


    def setLeggings(self, item: "ItemStack") -> None:
        """
        Sets the item currently being worn by the armor stand on its legs.

        Arguments
        - item: the item to wear

        See
        - .getEquipment()

        Deprecated
        - prefer
        EntityEquipment.setLeggings(org.bukkit.inventory.ItemStack)
        """
        ...


    def getChestplate(self) -> "ItemStack":
        """
        Returns the item currently being worn by the armor stand on its chest.

        Returns
        - the worn item

        See
        - .getEquipment()

        Deprecated
        - prefer EntityEquipment.getChestplate()
        """
        ...


    def setChestplate(self, item: "ItemStack") -> None:
        """
        Sets the item currently being worn by the armor stand on its chest.

        Arguments
        - item: the item to wear

        See
        - .getEquipment()

        Deprecated
        - prefer
        EntityEquipment.setChestplate(org.bukkit.inventory.ItemStack)
        """
        ...


    def getHelmet(self) -> "ItemStack":
        """
        Returns the item currently being worn by the armor stand on its head.

        Returns
        - the worn item

        See
        - .getEquipment()

        Deprecated
        - prefer EntityEquipment.getHelmet()
        """
        ...


    def setHelmet(self, item: "ItemStack") -> None:
        """
        Sets the item currently being worn by the armor stand on its head.

        Arguments
        - item: the item to wear

        See
        - .getEquipment()

        Deprecated
        - prefer
        EntityEquipment.setHelmet(org.bukkit.inventory.ItemStack)
        """
        ...


    def getBodyPose(self) -> "EulerAngle":
        """
        Returns the armor stand's body's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setBodyPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's body's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def getLeftArmPose(self) -> "EulerAngle":
        """
        Returns the armor stand's left arm's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setLeftArmPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's left arm's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def getRightArmPose(self) -> "EulerAngle":
        """
        Returns the armor stand's right arm's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setRightArmPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's right arm's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def getLeftLegPose(self) -> "EulerAngle":
        """
        Returns the armor stand's left leg's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setLeftLegPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's left leg's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def getRightLegPose(self) -> "EulerAngle":
        """
        Returns the armor stand's right leg's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setRightLegPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's right leg's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def getHeadPose(self) -> "EulerAngle":
        """
        Returns the armor stand's head's current pose as a
        org.bukkit.util.EulerAngle.

        Returns
        - the current pose
        """
        ...


    def setHeadPose(self, pose: "EulerAngle") -> None:
        """
        Sets the armor stand's head's current pose as a
        org.bukkit.util.EulerAngle.

        Arguments
        - pose: the current pose
        """
        ...


    def hasBasePlate(self) -> bool:
        """
        Returns whether the armor stand has a base plate.

        Returns
        - whether it has a base plate
        """
        ...


    def setBasePlate(self, basePlate: bool) -> None:
        """
        Sets whether the armor stand has a base plate.

        Arguments
        - basePlate: whether is has a base plate
        """
        ...


    def isVisible(self) -> bool:
        """
        Returns whether the armor stand should be visible or not.

        Returns
        - whether the stand is visible or not
        """
        ...


    def setVisible(self, visible: bool) -> None:
        """
        Sets whether the armor stand should be visible or not.

        Arguments
        - visible: whether the stand is visible or not
        """
        ...


    def hasArms(self) -> bool:
        """
        Returns whether this armor stand has arms.

        Returns
        - whether this has arms or not
        """
        ...


    def setArms(self, arms: bool) -> None:
        """
        Sets whether this armor stand has arms.

        Arguments
        - arms: whether this has arms or not
        """
        ...


    def isSmall(self) -> bool:
        """
        Returns whether this armor stand is scaled down.

        Returns
        - whether this is scaled down
        """
        ...


    def setSmall(self, small: bool) -> None:
        """
        Sets whether this armor stand is scaled down.

        Arguments
        - small: whether this is scaled down
        """
        ...


    def isMarker(self) -> bool:
        """
        Returns whether this armor stand is a marker, meaning it has a very small
        collision box.

        Returns
        - whether this is a marker
        """
        ...


    def setMarker(self, marker: bool) -> None:
        """
        Sets whether this armor stand is a marker, meaning it has a very small
        collision box.

        Arguments
        - marker: whether this is a marker
        """
        ...


    def addEquipmentLock(self, slot: "EquipmentSlot", lockType: "LockType") -> None:
        """
        Locks the equipment slot with the specified
        LockType locking mechanism.

        Arguments
        - slot: the equipment slot to lock
        - lockType: the LockType to lock the equipment slot with
        """
        ...


    def removeEquipmentLock(self, slot: "EquipmentSlot", lockType: "LockType") -> None:
        """
        Remove a LockType locking mechanism.

        Arguments
        - slot: the equipment slot to change
        - lockType: the LockType to remove
        """
        ...


    def hasEquipmentLock(self, slot: "EquipmentSlot", lockType: "LockType") -> bool:
        """
        Returns if the ArmorStand has the specified
        LockType locking mechanism.

        Arguments
        - slot: the EquipmentSlot to test
        - lockType: the LockType to test

        Returns
        - if the ArmorStand has been locked with the parameters specified
        """
        ...


    class LockType(Enum):
        """
        Represents types of locking mechanisms for ArmorStand equipment.
        """

        ADDING_OR_CHANGING = 0
        """
        Prevents adding or changing the respective equipment - players cannot
        replace the empty slot with a new item or swap the items between
        themselves and the ArmorStand.
        """
        REMOVING_OR_CHANGING = 1
        """
        Prevents removing or changing the respective equipment - players
        cannot take an item from the slot or swap the items between
        themselves and the ArmorStand.
        """
        ADDING = 2
        """
        Prevents adding the respective equipment - players cannot replace the
        empty slot with a new item, but can swap items between themselves and
        the ArmorStand.
        """



"""
Python module generated from Java source file org.bukkit.entity.Wither

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Wither(Monster, Boss):
    """
    Represents a Wither boss
    """

    def setTarget(self, target: "LivingEntity") -> None:
        """
        
        
        This method will set the target of the Head.CENTER center head of
        the wither.

        See
        - .setTarget(org.bukkit.entity.Wither.Head, org.bukkit.entity.LivingEntity)
        """
        ...


    def setTarget(self, head: "Head", target: "LivingEntity") -> None:
        """
        This method will set the target of individual heads Head of the
        wither.

        Arguments
        - head: the individual head
        - target: the entity that should be targeted
        """
        ...


    def getTarget(self, head: "Head") -> "LivingEntity":
        """
        This method will get the target of individual heads Head of the
        wither.

        Arguments
        - head: the individual head

        Returns
        - the entity targeted by the given head, or null if none is
        targeted
        """
        ...


    def getInvulnerabilityTicks(self) -> int:
        """
        Returns the wither's current invulnerability ticks.

        Returns
        - amount of invulnerability ticks
        """
        ...


    def setInvulnerabilityTicks(self, ticks: int) -> None:
        """
        Sets the wither's current invulnerability ticks.
        
        When invulnerability ticks reach 0, the wither will trigger an explosion.

        Arguments
        - ticks: amount of invulnerability ticks
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.world.SpawnChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit import World
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class SpawnChangeEvent(WorldEvent):
    """
    An event that is called when a world's spawn changes. The world's previous
    spawn location is included.
    """

    def __init__(self, world: "World", previousLocation: "Location"):
        ...


    def getPreviousLocation(self) -> "Location":
        """
        Gets the previous spawn location

        Returns
        - Location that used to be spawn
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.cache.Cache

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.cache import *
from com.google.common.collect import ImmutableMap
from com.google.common.util.concurrent import ExecutionError
from com.google.common.util.concurrent import UncheckedExecutionException
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import CompatibleWith
from com.google.errorprone.annotations import DoNotMock
from java.util.concurrent import Callable
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import ExecutionException
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Cache:
    """
    A semi-persistent mapping from keys to values. Cache entries are manually added using .get(Object, Callable) or .put(Object, Object), and are stored in the cache until either
    evicted or manually invalidated. The common way to build instances is using CacheBuilder.
    
    Implementations of this interface are expected to be thread-safe, and can be safely accessed
    by multiple concurrent threads.
    
    Type `<K>`: the type of the cache's keys, which are not permitted to be null
    
    Type `<V>`: the type of the cache's values, which are not permitted to be null

    Author(s)
    - Charles Fry

    Since
    - 10.0
    """

    def getIfPresent(self, key: "Object") -> "V":
        """
        Returns the value associated with `key` in this cache, or `null` if there is no
        cached value for `key`.

        Since
        - 11.0
        """
        ...


    def get(self, key: "K", loader: "Callable"["V"]) -> "V":
        """
        Returns the value associated with `key` in this cache, obtaining that value from `loader` if necessary. The method improves upon the conventional "if cached, return; otherwise
        create, cache and return" pattern. For further improvements, use LoadingCache and its
        LoadingCache.get(Object) get(K) method instead of this one.
        
        Among the improvements that this method and `LoadingCache.get(K)` both provide are:
        
        
          - LoadingCache.get(Object) awaiting the result of a pending load rather than
              starting a redundant one
          - eliminating the error-prone caching boilerplate
          - tracking load .stats statistics
        
        
        Among the further improvements that `LoadingCache` can provide but this method cannot:
        
        
          - consolidation of the loader logic to CacheBuilder.build(CacheLoader) a single
              authoritative location
          - LoadingCache.refresh refreshing of entries, including CacheBuilder.refreshAfterWrite automated refreshing
          - LoadingCache.getAll bulk loading requests, including CacheLoader.loadAll bulk loading implementations
        
        
        **Warning:** For any given key, every `loader` used with it should compute the same
        value. Otherwise, a call that passes one `loader` may return the result of another call
        with a differently behaving `loader`. For example, a call that requests a short timeout
        for an RPC may wait for a similar call that requests a long timeout, or a call by an
        unprivileged user may return a resource accessible only to a privileged user making a similar
        call. To prevent this problem, create a key object that includes all values that affect the
        result of the query. Or use `LoadingCache.get(K)`, which lacks the ability to refer to
        state other than that in the key.
        
        **Warning:** as with CacheLoader.load, `loader` **must not** return
        `null`; it may either return a non-null value or throw an exception.
        
        No observable state associated with this cache is modified until loading completes.

        Raises
        - ExecutionException: if a checked exception was thrown while loading the value
        - UncheckedExecutionException: if an unchecked exception was thrown while loading the
            value
        - ExecutionError: if an error was thrown while loading the value

        Since
        - 11.0
        """
        ...


    def getAllPresent(self, keys: Iterable["Object"]) -> "ImmutableMap"["K", "V"]:
        ...


    def put(self, key: "K", value: "V") -> None:
        """
        Associates `value` with `key` in this cache. If the cache previously contained a
        value associated with `key`, the old value is replaced by `value`.
        
        Prefer .get(Object, Callable) when using the conventional "if cached, return;
        otherwise create, cache and return" pattern.

        Since
        - 11.0
        """
        ...


    def putAll(self, m: dict["K", "V"]) -> None:
        """
        Copies all of the mappings from the specified map to the cache. The effect of this call is
        equivalent to that of calling `put(k, v)` on this map once for each mapping from key
        `k` to value `v` in the specified map. The behavior of this operation is undefined
        if the specified map is modified while the operation is in progress.

        Since
        - 12.0
        """
        ...


    def invalidate(self, key: "Object") -> None:
        """
        Discards any cached value for key `key`.
        """
        ...


    def invalidateAll(self, keys: Iterable["Object"]) -> None:
        ...


    def invalidateAll(self) -> None:
        """
        Discards all entries in the cache.
        """
        ...


    def size(self) -> int:
        """
        Returns the approximate number of entries in this cache.
        """
        ...


    def stats(self) -> "CacheStats":
        """
        Returns a current snapshot of this cache's cumulative statistics, or a set of default values if
        the cache is not recording statistics. All statistics begin at zero and never decrease over the
        lifetime of the cache.
        
        **Warning:** this cache may not be recording statistical data. For example, a cache
        created using CacheBuilder only does so if the CacheBuilder.recordStats method
        was called. If statistics are not being recorded, a `CacheStats` instance with zero for
        all values is returned.
        """
        ...


    def asMap(self) -> "ConcurrentMap"["K", "V"]:
        """
        Returns a view of the entries stored in this cache as a thread-safe map. Modifications made to
        the map directly affect the cache.
        
        Iterators from the returned map are at least *weakly consistent*: they are safe for
        concurrent use, but if the cache is modified (including by eviction) after the iterator is
        created, it is undefined which of the changes (if any) will be reflected in that iterator.
        """
        ...


    def cleanUp(self) -> None:
        """
        Performs any pending maintenance operations needed by the cache. Exactly which activities are
        performed -- if any -- is implementation-dependent.
        """
        ...
